﻿;;;-*- Mode: Lisp; Package: "ORI-ADDRESS" -*-
;;;===============================================================================
;;;11/04/04
;;;             AGENT CIT-ADDRESS: ONTOLOGY (file CIT-ADDRESS-ontology.lisp)
;;;             Copyright Barthes@UTC, 2011
;;;
;;;=============================================================================== 

#|
CIT-ADDRESS is one of the staff agent dpecialized in providing address information.
It can find email addressses, telephone numbers, web pages (?)

2011
 0404 reorganizing the file
|#

(in-package :CIT-ADDRESS)

(defontology 
  (:title "CIT-ADDRESS ontology")
  (:version "1.0")
  (:language :all)
  )

;;;===============================================================================
;;;
;;;                               CONCEPTS
;;;
;;;===============================================================================

;;;===============================================================================
;;;                                ADDRESS
;;;===============================================================================

(defconcept (:en "address" :fr "Adresse")
  (:doc :en "An ADDRESS can be different things:
   - a postal home address
   - a professional address
   - an email
   - a web address, i.e. the address of a personal web page
Each of those can be multiple."
        :fr "Une ADDRESSE peut être:
   - l'adresse du domicile
   - l'adresse professionnelle
   - l'adresse email ou courriel
   - une adress web, c'est-à-dire l'adresse du site personnel
Chacune de ces adresses peut être multiple."))

;;;===============================================================================
;;;                              ADDRESS (EMAIL)
;;;===============================================================================

(defconcept (:en "email address; email" :fr "adresse email; courriel")
  (:is-a "address")
  (:doc :en "An EMAIL ADDRESS is the code allowing to receive an ~
             electronic message."
        :fr "Une ADRESSE EMAIL ou COURRIEL est celle où l'on peut ~
		     recevoir un courrier électronique."
        )
  (:att (:en "e-address" :fr "e-adresse")))

;;;===============================================================================
;;;                               ADDRESS (HOME)
;;;===============================================================================

(defconcept (:en "home address; private address" 
                 :fr "domicile; adresse privée; adresse personnelle")
  (:is-a "postal address")
  (:doc :en "A HOME ADDRESS is the information needed to locate ~
             the place where a person is living."
        :fr "Le DOMICILE est l'adresse de l'endroit où la personne habite.")
  )

;;;===============================================================================
;;;                              ADDRESS (OFFICE)
;;;===============================================================================

(defconcept (:en "office address; professional address"
                 :fr "adresse professionnelle")
  (:is-a "postal address")
  (:doc :en "An OFFICE or PROFESSIONAL ADDRESS is the address of a place where a ~              
             person works."
        :fr "Une ADRESSE PROFESSIONNELLE est l'adresse du lieu où une personne ~
             travaille.")
  )

;;;===============================================================================
;;;                              ADDRESS (POSTAL)
;;;===============================================================================

(defconcept (:en "postal address" :fr "adresse postale")
  (:is-a "address")
  (:doc :en "A POSTAL ADDRESS is the information needed to locate ~
             the place where a person is living or working."
        :fr "L'ADRESSE POSTALE est l'adresse ou le courrier est distribué.")
  (:att (:en "street and number; street" :fr "rue"))
  (:rel (:en "town; city" :fr "ville") (:unique)(:to "town"))
  (:rel (:en "country" :fr "pays") (:unique)(:to "country"))
  (:att (:en "zip; postal code" :fr "code postal") (:unique)))

;;;===============================================================================
;;;                               ADDRESS (WEB)
;;;===============================================================================

(defconcept (:en "web address; web page; personal web page"
                 :fr "adresse web")
  (:doc :en "A WEB ADDRESS is the URL of a web page containing personal data."
        :fr "Une ADRESSE WEB est l'URL d'une page contenant des informations ~
             personnelles.")
  (:att (:en "URL" :fr "URL")))

;;;===============================================================================
;;;                                   CITY
;;;===============================================================================

(defconcept (:en "town; city" :fr "ville; cité")
  (:is-a "territory")
  (:att (:en "zip" :fr "code postal"))
  (:att (:en "state" :fr "état"))
  (:rel (:en "district" :fr "département") (:to "district"))
  (:rel (:en "country" :fr "pays") (:to "country"))
  )

;;;===============================================================================
;;;                                 COMPANY
;;;===============================================================================

(defconcept (:en "company; firm; enterprise" 
                 :fr "société; entreprise")
  (:is-a "organization")
  (:doc :en "A COMPANY, FIRM, or ENTERPRISE usually undertakes activities to make ~
             some profit for its owner(s)."
        :fr "Une SOCIETE, ou ENTREPRISE a en général des activités de façon à ~
             réaliser des profits pour ses propriétaires.")
  )

;;;===============================================================================
;;;                                 COUNTRY
;;;===============================================================================

(defconcept (:en "country" :fr "pays")
  (:is-a "territory")
  )

;;;===============================================================================
;;;                                   DATE
;;;===============================================================================

(defconcept (:en "date" :fr "date")
  (:att (:en "year" :fr "année"))
  (:att (:en "month" :fr "mois"))
  (:att (:en "jour" :fr "day"))
  (:att (:en "week day" :fr "jour de la semaine"))
  )

;;;===============================================================================
;;;                                 DISTRICT
;;;===============================================================================

(defconcept (:en "district" :fr "département")
  (:is-a "territory")
  (:att (:en "number" :fr "numéro"))
  (:rel (:en "region" :fr "région") (:to "region"))
  )

;;;===============================================================================
;;;                                  MEETING
;;;===============================================================================

(defconcept (:en "meeting" :fr "manifestation; rencontre; réunion; meeting")
  (:att (:en "name"))
  (:att (:en "acronym"))
  (:rel (:en "place" :fr "lieu") (:to "place"))
  (:att (:en "time" :fr "moment"))
  (:rel (:en "address" :fr "adresse") (:to "adresse"))
  (:rel (:en "President of the PC" :fr "président du comité de programme")
        (:to "person"))
  (:rel (:en "organizer" :fr "organisateur") (:to "person"))
  )

;;;===============================================================================
;;;                              MEETING (CONFERENCE)
;;;===============================================================================

(defconcept (:en "conference" :fr "congrès; colloque")
  (:is-a "meeting")
  )

;;;===============================================================================
;;;                              MEETING (WORKSHOP)
;;;===============================================================================

(defconcept (:en "workshop" :fr "séminaire")
  (:is-a "meeting")
  )

;;;===============================================================================
;;;                              MEETING (SYMPOSIUM)
;;;===============================================================================

(defconcept (:en "symposium" :fr "symposium")
  (:is-a "meeting")
  )
;;;===============================================================================
;;;                                ORGANIZATION
;;;===============================================================================

(defconcept (:en "organization" :fr "organisation")
  (:att (:en "name" :fr "nom") (:entry))
  (:att (:en "acronym" :fr "sigle") (:entry))
  (:rel (:en "subsidiary" :fr "filiale") (:to "organization"))
  (:rel (:en "division" :fr "division")(:to "organization"))
  (:rel (:en "department" :fr "département") (:to "organization"))
  (:rel (:en "address" :fr "adresse")(:to "address"))
  (:rel (:en "phone" :fr "téléphone") (:to "phone"))
  (:rel (:en "web page" :fr "site web") (:to "web page"))
  (:doc :en "An ORGANIZATION is a social structure private or public that has some ~
             social goals."
        :fr "Une ORGANISATION est une structure sociale privée o publique qui ~
             poursuit un but social.")
  ) 

;;;===============================================================================
;;;                            ORGANIZATION (TEACHING)
;;;===============================================================================

(defconcept (:en "teaching organization" :fr "organisme d'enseignement")
  (:is-a "organization")
  (:att (:en "level" :fr "niveau"))
  (:rel (:en "president" 
             :fr "président; directeur") (:to "person"))
  (:doc :en "A TEACHING ORGANIZATION is an organization that provides teaching to ~
             persons called students. It may be an elementary school, a standard ~
             school, a college, or a university."
        :fr "Un organisme d'enseignement est une organisation qui offre des cours ~
             à des personnes appelées étudiants. Ce peut être une école maternelle,~
             un collège, un lycée, ou une une université.")
  )

;;;===============================================================================
;;;                              ORGANIZATION (NON PROFIT)
;;;===============================================================================

(defconcept (:en "non profit organization" :fr "organisation sans but lucratif")
  (:is-a "organization")
  (:rel (:en "president" 
             :fr "président; directeur") (:to "person"))
  (:rel (:en "executive committee" :fr "bureau") (:to "person") (:min 2))
  (:doc :en "A NON PROFIT ORGANIZATION is not allowed to derive profits from its ~
             activities."
        :fr "Une ORGANISATION SANS BUT LUCRATIF est une organisation aui ne peut ~
             retirer des profits de ses activités.")
  )

;;;===============================================================================
;;;                                PERSON
;;;===============================================================================

(defconcept (:en "person" :fr "personne")
  (:att (:en "name" :fr "nom") (:entry))
  (:att (:en "first-name" :fr "prénom")(:entry))
  (:att (:en "trade" :fr  "métier"))
  (:rel (:en "home address" :fr "adresse privée; domicile")
        (:to "postal address"))
  (:rel (:en "address" :fr "adresse")(:to "postal address"))
  (:rel (:en "phone" :fr "téléphone")(:to "phone"))
  (:rel (:en "email" :fr "email") (:to "email"))
  (:rel (:en "web page" :fr "page web") (:to "web address"))
  (:rel (:en "work place" :fr "lieu de travail") (:to "work place"))
  (:rel (:en "employer" :fr "employeur") (:to "organization"))
  )

;;;===============================================================================
;;;                             PERSON (STUDENT)
;;;===============================================================================

(defconcept (:en "student" :fr "étudiant")
  (:doc :en "A STUDENT is a person who is registered in a higher education ~
             organization."
		:fr "Un étudiant est une personne inscrite dans une organisation ~
		     dispensant une formaion post baccalauréat.")
  (:is-a "person")
  (:rel (:en "school" :fr "école; université") (:to "university"))
  )

;;;===============================================================================
;;;                                  PLACE
;;;===============================================================================

(defconcept (:en "place" :fr "lieu; endroit")
  (:doc :en "A PLACE is part of a territory"
      :fr "Un LIEU est correspond à une partie de territoire")
  (:is-a "territory")
  (:rel (:en "location" :fr "localisation") (:to "territory"))
  (:rel (:en "address" :fr "adresse") (:to "address"))
  )

;;;===============================================================================
;;;                               TELEPHONE
;;;===============================================================================

(defconcept (:en "phone; telephone" :fr "téléphone")
  (:doc :en "A TELEPHONE is a means to talk when away. One can have different types ~
             of telephone number: home phone, office phone, cell phone, etc."
        :fr "Un TELEPHONE est un moyen qui permet de communiquer à distance par la ~
             voix. il y a plusieurs types de téléphones : le téléphone du domicile, ~
             le téléphone professionnel, le portable, etc.")
  (:att (:en "number" :fr "numéro"))
  )

;;;===============================================================================
;;;                              TELEPHONE (HOME)
;;;===============================================================================

(defconcept (:en "home phone; home telephone" 
                 :fr "téléphone du domicile; téléphone privé")
  (:doc :en "A HOME PHONE is a telephone installed at the private address of the ~
             owner."
        :fr "Le TELEPHONE DU DOMICILE est installé au domicile de son propriétaire.")
  (:is-a "phone")
  )

;;;===============================================================================
;;;                               TELEPHONE (OFFICE)
;;;===============================================================================

(defconcept (:en "office phone; office telephone" 
                 :fr "téléphone professionnel")
  (:doc :en "An OFFICE PHONE is a telephone installed at the work-place."
        :fr "Le TELEPHONE PROFESSIONNEL est celui de l'endroit où la personne ~
             travaille.")
  (:is-a "phone")
  )

;;;===============================================================================
;;;                               TELEPHONE (CELL)
;;;===============================================================================

(defconcept (:en "cell phone" :fr "portable; mobile")
  (:doc :en "A CELL PHONE is a portable telephone.")
  (:is-a "phone")
  )

;;;===============================================================================
;;;                                TERRITORY
;;;===============================================================================

(defconcept (:en "territory" :fr "territoire")
  (:att (:en "name" :fr "nom")(:entry))
  )

;;;===============================================================================
;;;                               TERRITORY (REGION)
;;;===============================================================================

(defconcept (:en "region" :fr "région")
  (:is-a "territory")  
  )
  
;;;===============================================================================
;;;                                UNIVERSITY
;;;===============================================================================

(defconcept (:en "university" :fr "université")
  (:is-a "teaching organization")
  (:doc :en "A UNIVERSITY is an organization involved in higher education."
        :fr "Une UNIVERSITE est un établissement d'enseignement supérieur.")
  )
  
;;;===============================================================================
;;;                                WORK PLACE
;;;===============================================================================

(defconcept (:en "Work Place" :fr "Lieu de travail")
  (:doc :en "A WORK PLACE is a place where people usually work."
     :fr "Un LIEU DE TRAVAIL est un endroit où les gens travaillent.")
  (:is-a "place")
  (:att (:en "acronym" :fr "sigle") (:entry))
  )
  
;;;===============================================================================
;;;
;;;                                 METHODS
;;;
;;;===============================================================================

;;;----------------------------------------------------------- (PERSON) =format-id

(definstmethod =format-id PERSON ()
  (list "name" (HAS-NAME) "first-name" (HAS-FIRST-NAME)))

;;;--------------------------------------------------- (ORGANIZATION) =get-address

(definstmethod =get-address ORGANIZATION ()
   "returns a list of lists each containing a string with the organization ~
    name and/or the acronym, and the address, or nil."
  (let ((address-list (has-address))
        (header (format nil "~{~A~^ ~}~@[ (~{~A~^ ~})~]"
		           (has-name) (has-acronym)))
		results)
     (cond
      (address-list
	    ;; must add organization name
	    (setq results (broadcast address-list '=summary))
		(setq results 
		  (mapcar #'(lambda (xx) (concatenate 'string header ", " (car xx)))
		             results)))
	  ((setq results header)))
	 results))
	 
#|
(send '$e-organization.7 '=get-address)
("Technological Institute of Parana (TECPAR), ?, Curitiba, Parana, Brazil")
(send '$E-UNIVERSITY.6 '=get-address)
("Universidade Pontifical do Parana (PUC), rua Immaculata Conceiçaõ, Curitiba, Parana, Brazil")
|#
;;;--------------------------------------------------------- (PERSON) =get-address

(definstmethod =get-address PERSON ()
   "returns a list with a string with the person name, first name, and ~
    address. If a person has no address, tries the work place address ~
	or else the employer's address"
  (let ((address-list (has-address))
        work-place-list employer-list)
    ;; if we have a specific address, use it
	(cond
      (address-list
	    (setq address-list (broadcast address-list '=summary))
		; (format t "~%; PERSON =get-address /address-list 1: ~%   ~S"
		    ; address-list)
			)
	  ;; try work-place
	  ((setq work-place-list (has-work-place))
	   (setq address-list (broadcast work-place-list '=get-address))
	   ; (format t "~%; PERSON =get-address /address-list 2: ~%   ~S"
		    ; address-list)
			)
	  ;; try employer
	  ((setq employer-list (has-employer))
	   (setq address-list 
	       (broadcast employer-list '=get-address))
	   ; (format t "~%; PERSON =get-address /address-list 3: ~%   ~S"
		    ; address-list)
			)
	  ;; otherwise address-list is empty
	  )

    (format nil "~{~A~^ ~}, ~{~A~^ ~}: ~{~{~A~^ ~}~^,~% ~}" 
       (or (has-first-name) '("?"))
	   (or (has-name) '("?"))
	   (or address-list '(("*unknown address*"))))
	 ))

#|
(send '$e-PERSON.3 '=get-address)
"Dominique, Barthès Barthès-Biesel: 14, Allée de la Tilloye, 60200 Compiègne, France,
 Université de Technologie de Compiègne, Centre de Recherche de Royallieu, Département de Génie Biomédical, 60206 ?"
|#
;;;----------------------------------------------------- (WORK-PLACE) =get-address

(definstmethod =get-address WORK-PLACE ()
   "returns a list of lists each containing a string with the organization ~
    name and/or the acronym, and the address, or nil."
  (let ((address-list (has-address))
        (header (format nil "~{~A~^ ~}~@[ (~{~A~^ ~})~]"
		           (has-name) (has-acronym)))
		results)
     (cond
      (address-list
	    ;; must add organization name
	    (setq results (broadcast address-list '=summary))
		(setq results 
		  (mapcar #'(lambda (xx) (concatenate 'string header ", " (car xx)))
		             results)))
	  ((setq results header)))
	 results))
	 
#|
(send '$e-organization.7 '=get-address)
("Technological Institute of Parana (TECPAR), ?, Curitiba, Parana, Brazil")
|#
;;;---------------------------------------------------- (PERSON) =get-home-address

(definstmethod =get-home-address PERSON ()
   "returns a list with a string with the person name, first name, and ~
    home address. If a person has no home address, return a sorry message."
  (let ((address-list (has-home-address)))
    ;; if we have a specific address, use it
	(if address-list
	    (setq address-list (broadcast address-list '=summary))
		; (format t "~%; PERSON =get-address /address-list 1: ~%   ~S"
		    ; address-list)
			)

    (format nil "~{~A~^ ~}, ~{~A~^ ~}: ~{~{~A~^ ~}~^,~% ~}" 
       (or (has-first-name) '("?"))
	   (or (has-name) '("?"))
	   (or address-list '(("*unknown home address*"))))
	 ))

#|
(SEND '$E-PERSON.2 '=GET-home-ADDRESS)
"Jean-Paul, Barthès: 14, Allée de la Tilloye, 60200 Compiègne, France"

(SEND '$E-PERSON.6 '=GET-home-ADDRESS)
"Madjid, Bouabdallah: *unknown home address*
|#	 
;;---------------------------------------------------- (PERSON ADRESS) =if-needed
;; JPB0911
;; Careful! =if-needed for a property should return a list of objects

; (defownmethod =if-needed ("address" "MOSS PROPERTY NAME" "MOSS RELATION" 
                          ; :class-ref "person")
  ; (obj-id)
  ; "when the access does not lead to an address, we try the working place, ~
   ; and then the employer"
  ; (let (item)
    ; the address is either the specified address or the address of the working
    ; place or the address of the employer
    ; (cond
     ; try the working place
     ; ((and 
       ; (setq item (car (send obj-id '=get "work place")))
       ; (send item '=get "address")))
     
     ; try next the employer
     ; ((and 
       ; (setq item (car (send obj-id '=get "employer")))
       ; (send item '=get "address"))))
    ; ))

; #|
; (send '$E-PERSON.21 '=get "adresse")
; ($E-POSTAL-ADDRESS.2)

; (setq _person-E.Scalabrin 
      ; (car (access '("personne" ("nom" :is "Scalabrin")("prénom" :is "Edson")))))
; ADDRESS::$E-PERSON.20
; (send _person-E.Scalabrin '=get "adresse")
; ($E-POSTAL-ADDRESS.5)
; |#
;;;------------------------------------------------------------ (COUNTRY) =summary

(definstmethod =summary COUNTRY ()
  (list (mln::get-canonical-name (car (has-name)))))
  
#|
(send '$e-country.2 '=summary)
("Brasil")
(let ((*language* :fr))
  (send '$e-country.2 '=summary))
("Brésil")
|#
;;;------------------------------------------------------ (EMAIL-ADDRESS) =summary

(definstmethod =summary EMAIL-ADDRESS ()
  (list (format nil "~{~A~^, ~}" (send *self* '=get 'HAS-E-ADDRESS))))

#|
(send '$e-email-address.1 '=summary)
("barthes@utc.fr")
|#
;;;------------------------------------------------------- (ORGANIZATION) =summary

(definstmethod =summary ORGANIZATION ()
  (list (format nil "~{~A ~}" (or (HAS-ACRONYM) (HAS-NAME)))))

;;;------------------------------------------------------------- (PERSON) =summary

(definstmethod =summary PERSON ()
  (list (format nil "~{~A~^, ~}~@[: ~{~A~^, ~}~]" 
             (HAS-NAME) (HAS-FIRST-NAME))))

#|
(send '$e-person.2 '=summary)
("Barthès: Jean-Paul")
(send '$e-person.3 '=summary)
("Barthès, Barthès-Biesel: Dominique")
|#
;;;----------------------------------------------------- (POSTAL-ADDRESS) =summary

(definstmethod =summary POSTAL-ADDRESS ()
  (list (format nil "~@[~{~A~^, ~}, ~]~@[~A ~]~{~{~A~^ ~}~^ ~}"
                 (has-street-and-number)
				 (car (has-zip))
				 (or (and (has-town)(broadcast (has-town) '=summary))
				     '(("?")))
				 )))
				 
#|
(send '$e-postal-address.2 '=summary)
("CEFET, Curitiba, Parana, Brasil")
|#				 
;;;-------------------------------------------------------------- (PHONE) =summary

(definstmethod =summary PHONE ()
  (list (format nil "~{~A~^, ~}" (HAS-NUMBER))))

;;;--------------------------------------------------------------- (TOWN) =summary

(definstmethod =summary TOWN ()
  (let ((country (car (has-country))))
	(list (format nil "~{~A~^ ~}~@[, ~{~A~^ ~}~]~@[, ~{~A~^ ~}~]"
	        (or (has-name) '("?"))
			(has-state)
			(if country (send country '=summary))))))
				  
#|
(SEND '$E-TOWN.2 '=SUMMARY)
("Compiègne, France")

(SEND '$E-TOWN.3 '=SUMMARY)
("Curitiba, Parana, Brazil"))
|#
;;;-------------------------------------------------------- (WEB-ADDRESS) =summary

(definstmethod =summary WEB-ADDRESS ()
  (list (format nil "~{~A~^, ~}" (send *self* '=get 'HAS-URL))))



;;;===============================================================================
;;;===============================================================================
;;;
;;;                                INDIVIDUALS
;;;
;;;===============================================================================
;;;===============================================================================

;;;=================================================================== TERRITORIES 

(defindividual "country"
  ("name" (:en "France" :fr "France"))
  )

(defindividual "country"
  ("name" (:en "Brazil" :fr "Brésil"))
  )

(defindividual "country"
  ("name" (:en "Mexico" :fr "Mexique"))
  )

(defindividual "country"
  ("name" (:en "Japan" :fr "Japon"))
  )

;;;======================================================================== CITIES 

(defindividual "town"
   ("name" "Chiba")
   ("country" "japan")
   )
   
(defindividual "town"
   ("name" "Compiègne")
   ("country" "france")
   )
(defindividual "town"
   ("name" "Curitiba")
   ("state" "Parana")
   ("country" "brazil")
   )
   
(defindividual "town"
   ("name" "Guadelajara")
   ("state" "Jalisco")
   ("country" "brazil")
   )
   
(defindividual "town"
   ("name" "Tsudanuma")
   ("country" "japan")
   )
   
;;;======================================================================== PEOPLE 

(defchapter
  (:name :en "individual persons"))

(defindividual "person"
  ("name" "de Azevedo")
  ("first name" "Hilton")
  ("employer" "cefet")
  (:doc :en "Dr. Hilton de Azevedo is working at CEFET."
        :fr "Le Dr. Hilton de Azevedo est professeur au CEFET.")
  (:var _hda)
  )

(defindividual "person"
  ("name" "Barthès")
  ("first name" "Jean-Paul")
  ("work-place" "CRR")
  ("employer" "UTC")
  ("home address" 
      (:new  "home address"
        (:doc :en "The address of Jean-Paul Barthès."
              :fr "L'adresse de Jean-Paul Barthès.")
        ("street" "14, Allée de la Tilloye")
        ("town" "Compiègne")
        ("zip" "60200")
        (:var _jpb-addr)))
  ("email" (:new "email"
                 ("e-address" "barthes@utc.fr")))
  ("web page" (:new "web page"
                    ("URL" "http://www.utc.fr/~barthes")))
  ("phone" 
   (:new  "home phone"
          ("number" "+33 (0)3 44 20 31 37")
          (:var _jpb-home-phone))
   (:new "office phone"
         ("number" "+33 (0)3 44 23 44 66"))
   (:new "cell phone"
         ("number" "+33 (0)6 80 45 32 67")))
  (:var _jpb)
  (:doc :en "Jean-Paul Barthès is a professor at University of ~
             Technology of Compiègne."
        :fr "Jean-Paul barthès est professeur à l'UTC.")
  )

(defindividual "person"
  ("name" "Barthès" "Barthès-Biesel" )
  ("first name" "Dominique")
  ("home address" _jpb-addr)
  ("work place" "BMBI")
  ("email" (:new "email"
                 ("e-address" "dbb@utc.fr")))
  ("phone" _jpb-home-phone 
   (:new "office phone"
         ("number" "+33 (0)3 44 23 43 93"))
   (:new "cell phone"
         ("number" "+33 (0)6 81 24 46 66")))
  (:var _dbb)
  (:doc :en 
        "Dominique Barthès Biesel is a professor at University of Technology ~
         of Compiègne."
        :fr "Dominique Barthès-Biesel est professeur à l'UTC")
  )

(defindividual "person"
  ("name" "Barthès")
  ("first name" "Camille")
  ("email" (:new "email"
                 ("e-address" "kangming421@126.com")))
  ("phone" 
   (:new "home phone"
         ("number" "+86 571 8701 0782"))
   (:new "cell phone"
         ("number" "+86 134 5678 3173")))
  (:var _cxb)
  (:doc :en "Camille Barthès is a Chinese coolie living currently at Qingdao."
        :fr "Camille Barthès est un coolie chinois qui habite Qingdao.")
  )

(defindividual "person"
  ("name" "Bonnifait")
  ("first name" "Philippe")
  ("work place" "CRR")
  (:doc :fr "Philippe Bonnifait est professeur à l'UTC")
  )

(defindividual "person"
  ("name" "Bouabdallah")
  ("first name" "Madjid")
  ("work place" "CRR")
  (:doc :fr "Madjid Bouabdallah est professeur à l'UTC et chercheur au laboratoire HEUDIASYC.")
  )

(defindividual "person"
  ("name" "Charara")
  ("first name" "Ali")
  ("employer" "utc")
  (:doc :fr "Ali Charara est le directeur du laboratoire HEUDIASYC à l'UTC")
  )

(defindividual "person"
  ("name" "Charreyron")
  ("first name" "Pierre-Olivier")
  ("employer" "UTC")
  (:doc :en "P.O. Charreyron is the president of UTC."
        :fr "P.O. Charreyron est le président de l'UTC")
  (:var _poc)
  )
  
(defindividual "student"
  ("name" "Chen")
  ("first name" "Kejia")
  (:var _kc)
  (:doc :en "Kejia Chen was a PhD student at UTC and is now teaching at Nanjing."
        :fr "Kejia Chen était doctorante à l'UTC et est MC à Nanjing.")
  )

(defindividual "person"
  ("name" "Denoeux")
  ("first name" "Thierry")
  ("employer" "utc")
  (:doc :fr "Thierry Denoeux est professeur à l'UTC et directeur adjoint du laboratoire HEUDIASYC.")
  )

(defindividual "person"
  ("name" "Dubuisson")
  ("first name" "Bernard")
  ("employer" "utc")
  (:doc :fr "Bernard Dubuisson est professeur à l'UTC et conseiller à la DGA.")
  )

(defindividual "person"
  ("name" "Enembreck")
  ("first name" "Fabricio")
  ("employer" "puc")
  (:doc :en "Dr. Fabricio Enembreck is working at PUC."
        :fr "Le Dr. Fabricio Enembreck est professeur à la PUC.")
  (:var _fe)
  )

(defindividual "person"
  ("name" "Fontaine")
  ("first name" "Dominique")
  (:var _df)
  (:doc :fr "Dominique Fontaine est maître de conférences at UTC."
        :en "Dominique Fontaine is an assistant professor at UTC.")
  ("employer" "utc")
  )

(defindividual "person"
  ("name" "Lourdeaux")
  ("first name" "Domitile")
  ("employer" "utc")
  (:doc :fr "Domitile Lourdeaux est enseignant-chercheur à l'UTC."
        :en "Domitile Lourdeaux is an assistant professor at UTC.")
  )

(defindividual "person"
  ("name" "Lozano")
  ("first name" "Rogelio")
  ("employer" "utc")
  (:doc :fr "Rogelio Lozano est chercheur dans le laboratoire HEUDIASYC et directeur de l'UMI franco-mexicaine."
        :en "Rogelio Lozano is a CNRS researcher at UTC and the director of the Franco-Mexican UMI laboratory.")
  )

(defindividual "person"
  ("nom" "Manabe")
  ("first name" "Yusuke")
  (:doc :en "Yusuke Manabe is an assistant professor at CIT.")
  ("phone" (:new "cell phone" ("number" "+81 12 34 56 78")))
  )

(defindividual "person"
  ("nom" "Mathieu")
  ("first name" "Philippe")
  (:doc :fr "Philippe Mathieu est professeur d'informatique à Lille 1.")
  (:var _pm)
  )

(defindividual "person"
  ("name" "Paraiso")
  ("first name" "Emerson")
  ("employer" "PUC")
  (:doc :en "Dr. Emerson Paraiso is working at PUC."
        :fr "Le docteur Emerson Paraiso est professeur à la PUC")
  (:var _ep)
  )

(defindividual "person"
  ("name" "Real")
  ("trade" "taxi")
  ("phone" (:new "cell phone" ("number" "+33 (0)6 07 54 02 27")))
  (:doc :en "Real had a deal with UTC to drive persons at a decent cost ~
             but unfortunately died in 2008.")
  )

; (defindividual "person"
  ; ("name" "Stephan")
  ; ("first name" "Ronan")
  ; ("phone" (:new "cell phone" ("number" "+33 (0)3 44 23 44 23")))
  ; ("address" _utc-addr)
  ; (:doc :en "Stephan is the president of UTC."
        ; :fr "Ronan Stephan est le président de l'UTC."
		; :en "Ronan Stephan is the president of UTC.")
  ; (:var _rs)
  ; )

(defindividual "person"
  ("name" "Ramos")
  ("first name" "Milton")
  ("employer" "tecpar")
  (:doc :en "Dr. Milton Ramos is working at TECPAR."
        :fr "Le Dr. Milton Ramos est responsable des activités IA au TECPAR.")
  (:var _mr)
  )

(defindividual "person"
  ("name" "Ramos")
  ("first name" "Feliz")
  ("employer" "CINVESTAV")
  (:doc :en "Dr. Felix Ramos is working at CINVESTAV.")
  (:var _fr)
  )

(defindividual "person"
  ("name" "Scalabrin")
  ("first name" "Edson")
  ("employer" "PUC")
  (:doc :en "Dr. Edson Scalabrin is working at PUC"
        :fr "Le Dr. Edson Scalabrin est professeur à la PUC.")
  (:var _es)
  )

(defindividual "person"
  ("name" "Sugawara")
  ("first name" "Kenji")
  ("employer" "CIT")
  (:doc :en "Prof. Sugawara is working at CIT in Japan."
        :fr "Le Prof. Sugawara est professeur au CIT.")
  (:var _hs)
  )

(defindividual "person"
  ("name" "Tacla")
  ("first name" "Cesar")
  ("employer" "CEFET")
  (:doc :en "Dr. Cesar Tacla is working at PUC")
  (:var _es)
  )

;;;---------- students

(defindividual "student"
  ("name" "Sato")
  ("first name" "Gilson")
  ("phone" (:new "office phone"
                 ("number" "+33 (0)3 44 23 44 23 ext: 4202")))
  ("address" _crr-addr)
  ("school" _UTC)
  (:doc :fr "Gilson Sato était doctorant à l'UTC."
        :en "Gilson is a professor at CEFET.")
  (:var _gs)
  )

;;;=================================================================== WORK PLACES
		   
(defindividual "work place"
   ("name" "Centre de Recherche de Royallieu")
   ("acronym" "CRR")
   ("address"
      (:new "postal address"
         (:doc :en "The address of UTC Research Center"
               :fr "L'adresse du Centre de recherches de Royllieu")
         ("street" "BP 20529")
         ("town" "Compiègne")
         ("zip" "60205")
		 (:var _crr-addr)))
    )

(defindividual "work place"
    ("name" "UMR CNRS 6599 Heudiasyc")
	("acronym" "Heudiasyc")
	("address" _crr-addr)
	)
	
(defindividual "work place"
   ("name" "UMR CNRS 6600 BMBI")
   ("acronym" "BMBI")
   ("address" _crr-addr)
   )
	
;;;================================================================= ORGANIZATIONS 

(defindividual "organization"
  ("name" "Délégation Générale pour l'Armement")
  ("acronym" "DGA")
  ("division"
   (:new "organization"
         ("name" "direction des systèmes de forces et des stratégies ~
           industrielle, technologique et de coopération.")
         ("acronym" "D4S"))
   (:new "organization"
         ("acronym" "MRIS")
         ("name" "Mission pour la Recherche et l'Innovation Scientifique"))
   )
  (:doc :fr "Maître d'ouvrage des programmes d'armement, la DGA est  ~
             responsable de la conception, de l'acquisition et de ~
			 l'évaluation des systèmes qui équipent les forces armées. ~
			 Son action couvre toute la durée de vie de ces programmes.")
	)

(defindividual "university"
  ("name" "Chiba Institute of technology")
  ("acronym" "CIT")
  ("address"
     (:new "postal address"
       (:doc :en "The address of CIT" :fr "L'adresse de CIT")
       ("town" "tsudanuma")
       (:var _cit-addr)))
  )
  
(defindividual "university"
  ("name" "Universidade Pontifical do Parana")
  ("acronym" "PUC")
  ("address" (:new "postal address"
                   (:doc "The address of PUC")
                   ("street" "rua Immaculata Conceiçaõ")
                   ("town" "Curitiba")))
  (:var _PUC)
  )
  
(defindividual "university"
  ("name" "Universidade Federal do Tecnologia do Parana")
  ("acronym" "UTFPR" "CEFET")
  ("address"
     (:new "postal address"
       (:doc :en "The address of CEFET" :fr "L'adresse du CEFET")
       ("town" "Curitiba")
	   ("state" "Parana")
	   ))
  )
  
(defindividual "university"
  ("name" "Université de Technologie de Compiègne")
  ("acronym" "UTC")
  ("address" 
    (:new "postal address"
          (:doc "The address of UTC")
          ("street" "rue Roger Couttolenc")
          ("town" "Compiègne")
          ("zip" "60200")))
  ("president" "Charreyron")
  ("phone" (:new "office phone"
                 ("number" "+33 3 44 32 44 23")))
  )

(defindividual "organization"
  ("name" "Centre National pour la Recherche Scientifique")
  ("acronym" "CNRS")
  (:var _cnrs)
  )
  
(defindividual "organization"
  ("acronym" "CINVETAV")
  ("address"
     (:new "postal address"
       (:doc :en "The address of Cinvestav" :fr "L'adresse de Cinvestav")
       ("town" "Guadelajara")
       (:var _cinvestav-addr)))
  )
  
(defindividual "organization"
  ("name" "Technological Institute of Parana")
  ("acronym" "TECPAR")
  ("address"
     (:new "postal address"
       (:doc :en "The address of TECPAR" :fr "L'adresse du TECPAR")
       ("town" "Curitiba")
       (:var _tecpar-addr)))
  )

(defindividual "non profit organization"
  ("name" "Institut International pour l'Intelligence Artificielle")
  ("acronym" "IIIA")
  ("address" (:new "postal address" 
                   ("street" "Centre de Transfert" "66 avenue de Landshut")
                   ("town" "Compiègne")("zip" "60200")))
  ("phone" (:new "cell phone"
                 ("number" "+33 6 80 45 32 67")))
  ("president" _jpb)
  (:var _IIIA)
  )

;;;====================================================================== MEETINGS 

(defindividual "manifestation"
  ("nom" "Journées Francophones pour les Systèmes Multi-Agents")
  ("sigle" "JFSMA")
  ("président du comité de programme" _pm)
  ("adresse"
   (:new "adresse postale"
         ("rue" "Hotel Terminus")
         ("ville" "Carcassonne")))
  ("time" "octobre")
  (:doc :fr "Les Journées Francophones pour les Systèmes Multi-Agents sont une ~
             manifestation annuelle regroupant des chercheurs de langue française.")
  (:var _jfsma))

;;;=============================================================================== 

:EOF