﻿;;;-*- Mode: Lisp; Package: "ARS-ADDRESS" -*-
;;;===============================================================================
;;;10/11/21
;;;             AGENT ARS-ADDRESS: ONTOLOGY (file stevens-ontology.lisp)
;;;             Copyright Barthes@UTC, 2006-2010
;;;
;;;=============================================================================== 

#|
ADDRESS is one of the staff agent dpecialized in providing address information.
It can find email addressses, telephone numbers, web pages (?)

2007
 0312 correcing some slight mistakes
 0824 changing accents for PC! Old file saved in .mac
 1019 changing has-country atribute to relation in address
2008
 1201 adding DGA
2009
 0125 encodage en UTF-8 utilisant Notepad++
 0801 setting package to ARS-ADDRESS
2010
 0616 cleaning a little bit
 1121 pgrade to OMAS v8.0.8
|#

(in-package :ARS-ADDRESS)

(defontology 
  (:title "ARS-ADDRESS ontology")
  (:version "1.0")
  (:language :all)
  )

;;;-------------------------------------------------------------------------------
;;;                               ADDRESS
;;;-------------------------------------------------------------------------------

(defconcept (:en "address" :fr "Adresse")
  (:doc :en "An ADDRESS can be different things:
   - a postal home address
   - a professional address
   - an email
   - a web address, i.e. the address of a personal web page
Each of those can be multiple."
        :fr "Une ADDRESSE peut être:
   - l'adresse du domicile
   - l'adresse professionnelle
   - l'adresse email ou courriel
   - une adress web, c'est-à-dire l'adresse du site personnel
Chacune de ces adresses peut être multiple."))

;;;-------------------------------------------------------------------------------
;;;                              CELL PHONE
;;;-------------------------------------------------------------------------------

(defconcept (:en "cell phone" :fr "portable; mobile")
  (:doc :en "A CELL PHONE is a portable telephone.")
  (:is-a "phone")
  )

;;;-------------------------------------------------------------------------------
;;;                               CITY
;;;-------------------------------------------------------------------------------

(defconcept (:en "city; town" :fr "ville; cité")
  (:is-a "territory")
  (:att (:en "zip" :fr "code postal"))
  (:rel (:en "district" :fr "département") (:to "district"))
  )

;;;-------------------------------------------------------------------------------
;;;                               COMPANY
;;;-------------------------------------------------------------------------------

(defconcept (:en "company; firm; enterprise" 
                 :fr "société; entreprise")
  (:is-a "organization")
  (:doc :en "A COMPANY, FIRM, or ENTERPRISE usually undertakes activities to make ~
             some profit for its owner(s)."
        :fr "Une SOCIETE, ou ENTREPRISE a en général des activités de façon à ~
             réaliser des profits pour ses propriétaires.")
  )

;;;-------------------------------------------------------------------------------
;;;                               CONGRESS
;;;-------------------------------------------------------------------------------

(defconcept (:en "congress" :fr "congrès; colloque")
  (:is-a "meeting")
  )

;;;-------------------------------------------------------------------------------
;;;                               COUNTRY
;;;-------------------------------------------------------------------------------

(defconcept (:en "country" :fr "pays")
  (:is-a "territory")
  )

;;;-------------------------------------------------------------------------------
;;;                                DATE
;;;-------------------------------------------------------------------------------

(defconcept (:en "date" :fr "date")
  (:att (:en "year" :fr "année"))
  (:att (:en "month" :fr "mois"))
  (:att (:en "jour" :fr "day"))
  (:att (:en "week day" :fr "jour de la semaine"))
  )

;;;-------------------------------------------------------------------------------
;;;                               DISTRICT
;;;-------------------------------------------------------------------------------

(defconcept (:en "district" :fr "département")
  (:is-a "territory")
  (:att (:en "number" :fr "numéro"))
  (:rel (:en "region" :fr "région") (:to "region"))
  )

;;;-------------------------------------------------------------------------------
;;;                              EMAIL ADDRESS
;;;-------------------------------------------------------------------------------

(defconcept (:en "email address; email" :fr "adresse email; courriel")
  (:is-a "address")
  (:doc :en "An EMAIL ADDRESS is the code allowing to receive an electronic message."
        :fr "Une ADRESSE EMAIL ou COURRIEL est celle où l'on peut recevoir un ~
             courrier électronique."
        )
  (:att (:en "e-address" :fr "e-adresse"))
  )

;;;-------------------------------------------------------------------------------
;;;                             HOME ADDRESS
;;;-------------------------------------------------------------------------------

(defconcept (:en "home address; private address" 
                 :fr "domicile; adresse privée; adresse personnelle")
  (:is-a "postal address")
  (:doc :en "A HOME ADDRESS is the information needed to locate ~
             the place where a person is living."
        :fr "Le DOMICILE est l'adresse de l'endroit où la personne habite.")
  )

;;;-------------------------------------------------------------------------------
;;;                               HOME PHONE
;;;-------------------------------------------------------------------------------

(defconcept (:en "home phone; home telephone" 
                 :fr "téléphone du domicile; téléphone privé")
  (:doc :en "A HOME PHONE is a telephone installed at the private address of the ~
             owner."
        :fr "Le TELEPHONE DU DOMICILE est installé au domicile de son propriétaire.")
  (:is-a "phone")
  )

;;;-------------------------------------------------------------------------------
;;;                               MEETING
;;;-------------------------------------------------------------------------------

(defconcept (:en "meeting" :fr "manifestation; rencontre; réunion; meeting")
  (:att (:en "name" :fr "nom"))
  (:att (:en "acronym" :fr "sigle"))
  (:rel (:en "place" :fr "lieu") (:to "place"))
  (:att (:en "time" :fr "moment"))
  (:rel (:en "address" :fr "adresse") (:to "adresse"))
  (:rel (:en "President of the PC" :fr "président du comité de programme")
        (:to "person"))
  (:rel (:en "organizer" :fr "organisateur") (:to "person"))
  )

;;;-------------------------------------------------------------------------------
;;;                          NON PROFIT ORGANIZATION
;;;-------------------------------------------------------------------------------

(defconcept (:en "non profit organization" :fr "organisation sans but lucratif")
  (:is-a "organization")
  (:rel (:en "president" 
             :fr "président; directeur") (:to "person"))
  (:rel (:en "executive committee" :fr "bureau") (:to "person") (:min 2))
  (:doc :en "A NON PROFIT ORGANIZATION is not allowed to derive profits from its ~
             activities."
        :fr "Une ORGANISATION SANS BUT LUCRATIF est une organisation aui ne peut ~
             retirer des profits de ses activités.")
  )

;;;-------------------------------------------------------------------------------
;;;                             OFFICE ADDRESS
;;;-------------------------------------------------------------------------------

(defconcept (:en "office address; professional address"
                 :fr "adresse professionnelle")
  (:is-a "postal address")
  (:doc :en "An OFFICE or PROFESSIONAL ADDRESS is the address of a place where a ~              
             person works."
        :fr "Une ADRESSE PROFESSIONNELLE est l'adresse du lieu où une personne ~
             travaille.")
  )

;;;-------------------------------------------------------------------------------
;;;                               OFFICE PHONE
;;;-------------------------------------------------------------------------------

(defconcept (:en "office phone; office telephone" 
                 :fr "téléphone professionnel")
  (:doc :en "An OFFICE PHONE is a telephone installed at the work-place."
        :fr "Le TELEPHONE PROFESSIONNEL est celui de l'endroit où la personne ~
             travaille.")
  (:is-a "phone")
  )

;;;-------------------------------------------------------------------------------
;;;                               ORGANIZATION
;;;-------------------------------------------------------------------------------

(defconcept (:en "organization" :fr "organisation")
  (:att (:en "name" :fr "nom") (:entry))
  (:att (:en "acronym" :fr "sigle") (:entry))
  (:rel (:en "subsidiary" :fr "filiale") (:to "organization"))
  (:rel (:en "division" :fr "division")(:to "organization"))
  (:rel (:en "department" :fr "département") (:to "organization"))
  (:rel (:en "part" :fr "partie") (:to "structure"))
  (:rel (:en "address" :fr "adresse")(:to "address"))
  (:rel (:en "phone" :fr "téléphone") (:to "phone"))
  (:rel (:en "web page" :fr "site web") (:to "web page"))
  (:doc :en "An ORGANIZATION is a social structure private or public that has some ~
             social goals."
        :fr "Une ORGANISATION est une structure sociale privée o publique qui ~
             poursuit un but social.")
  )

;;;-------------------------------------------------------------------------------
;;;                               PERSON
;;;-------------------------------------------------------------------------------

(defconcept (:en "person" :fr "personne")
  (:att (:en "name" :fr "nom") (:entry))
  (:att (:en "first-name" :fr "prénom")(:entry))
  (:att (:en "trade" :fr  "métier"))
  (:rel (:en "address" :fr "adresse")(:to "postal address"))
  (:rel (:en "phone" :fr "téléphone")(:to "phone"))
  (:rel (:en "email" :fr "email") (:to "email"))
  (:rel (:en "web page" :fr "page web") (:to "web address"))
  (:rel (:en "employer" :fr "employeur") (:to "organization"))
  (:rel (:en "membership" :fr "appartenance")(:to "organization"))
  (:rel (:en "work place" :fr "lieu de travail")(:to "place"))
  )

;;;-------------------------------------------------------------------------------
;;;                               PLACE
;;;-------------------------------------------------------------------------------

(defconcept (:en "place" :fr "lieu; endroit")
  (:att (:en "name" :fr "nom"))
  (:rel (:en "location" :fr "localisation") (:to "territory"))
  (:rel (:en "address" :fr "adresse") (:to "address"))
  )

;;;-------------------------------------------------------------------------------
;;;                             POSTAL ADDRESS
;;;-------------------------------------------------------------------------------

(defconcept (:en "postal address" :fr "adresse postale")
  (:is-a "address")
  (:doc :en "A POSTAL ADDRESS is the information needed to locate ~
             the place where a person is living or working."
        :fr "L'ADRESSE POSTALE est l'adresse ou le courrier est distribué.")
  (:att (:en "street and number; street" :fr "rue"))
  (:att (:en "town; city" :fr "ville") (:unique))
  (:rel (:en "country" :fr "pays") (:unique)(:to "country"))
  (:att (:en "zip; postal code" :fr "code postal") (:unique))
  (:att (:fr "cedex"))
  )

;;;-------------------------------------------------------------------------------
;;;                               REGION
;;;-------------------------------------------------------------------------------

(defconcept (:en "region" :fr "région")
  (:is-a "territory")
  (:rel (:en "country" :fr "pays") (:to "country"))  
  )

;;;-------------------------------------------------------------------------------
;;;                              STRUCTURE
;;;-------------------------------------------------------------------------------

(defconcept (:en "structure" :fr "structure")
  (:att (:en "name" :fr "nom") (:entry))
  (:att (:en "acronyme" :fr "sigle")(:entry))
  (:rel (:en "location" :fr "localisation") (:to "place"))
  )

;;;-------------------------------------------------------------------------------
;;;                               STUDENT
;;;-------------------------------------------------------------------------------

(defconcept (:en "student" :fr "étudiant")
  (:is-a "person")
  (:rel (:en "school" :fr "école") (:to "university"))
  )

;;;-------------------------------------------------------------------------------
;;;                               SYMPOSIUM
;;;-------------------------------------------------------------------------------

(defconcept (:en "symposium" :fr "symposium")
  (:is-a "meeting")
  )

;;;-------------------------------------------------------------------------------
;;;                               TELEPHONE
;;;-------------------------------------------------------------------------------

(defconcept (:en "phone; telephone" :fr "téléphone")
  (:doc :en "A TELEPHONE is a means to talk when away. One can have different types ~
             of telephone number: home phone, office phone, cell phone, etc."
        :fr "Un TELEPHONE est un moyen qui permet de communiquer à distance par la ~
             voix. il y a plusieurs types de téléphones : le téléphone du domicile, ~
             le téléphone professionnel, le portable, etc.")
  (:att (:en "number" :fr "numéro"))
  )

;;;-------------------------------------------------------------------------------
;;;                          TEACHING ORGANIZATION
;;;-------------------------------------------------------------------------------

(defconcept (:en "teaching organization" :fr "organisme d'enseignement")
  (:is-a "organization")
  (:att (:en "level" :fr "niveau"))
  (:rel (:en "president" 
             :fr "président; directeur") (:to "person"))
  (:doc :en "A TEACHING ORGANIZATION is an organization that provides teaching to ~
             persons called students. It may be an elementary school, a standard ~
             school, a college, or a university."
        :fr "Un organisme d'enseignement est une organisation qui offre des cours ~
             à des personnes appelées étudiants. Ce peut être une école maternelle, ~
             un collège, un lycée, ou une une université.")
  )

;;;-------------------------------------------------------------------------------
;;;                               TERRITORY
;;;-------------------------------------------------------------------------------

(defconcept (:en "territory" :fr "territoire")
  (:att (:en "name" :fr "nom"))
  )

;;;-------------------------------------------------------------------------------
;;;                               UNIVERSITY
;;;-------------------------------------------------------------------------------

(defconcept (:en "university" :fr "université")
  (:is-a "teaching organization")
  (:doc :en "A UNIVERSITY is an organization involved in higher education."
        :fr "Une UNIVERSITE est un établissement d'enseignement supérieur.")
  )

;;;-------------------------------------------------------------------------------
;;;                              WEB ADDRESS
;;;-------------------------------------------------------------------------------

(defconcept (:en "web address; web page; personal web page"
                 :fr "adresse web")
  (:doc :en "A WEB ADDRESS is the URL of a web page containing personal data."
        :fr "Une ADRESSE WEB est l'URL d'une page contenant des informations ~
             personnelles.")
  (:att (:en "URL" :fr "URL"))
  )

;;;-------------------------------------------------------------------------------
;;;                               WORKSHOP
;;;-------------------------------------------------------------------------------

(defconcept (:en "workshop" :fr "séminaire")
  (:is-a "meeting")
  )


;;;===============================================================================
;;;
;;;                                METHODS
;;;
;;;===============================================================================

#|
;;; here we need some simple function to select the name of the property according
;;; to the current language

(definstmethod =format-id PERSON ()
  (list "name" (HAS-NAME) "first-name" (HAS-FIRST-NAME)))


? (send '$E-PERSON.2 '=format-id)
("name" ("Barthès") "first-name" ("Jean-Paul"))
|#
;;;--------------------------------------------------- =get-address (ORGANIZATION)

(definstmethod =get-address ORGANIZATION ()
  (let ((owner (car (send *self* '=summary)))
        (addresses (send *self* '=get "address")))
    ;; all adresses are recorded through the address relation
    (cond
     (addresses
      (list (format nil "~A~%~{  ~{~A~}~^~%~}" owner 
                    (broadcast addresses '=summary))))
     ((list (format nil "~A - Adresse inconnue." owner))))))

#|
? (send '$E-UNIVERSITY.2 '=get-address)
("UTC 
  rue Roger Couttolenc, 60200 Compiègne")

? (send '$E-ORGANIZATION.2 '=get-address)
("CNRS - Adresse inconnue.")
|#
;;;--------------------------------------------------------- =get-address (PERSON)

(definstmethod =get-address PERSON ()
  (let ((owner (car (send *self* '=summary)))
        (addresses (send *self* '=get "address")))
    ;; all adresses are recorded through the address relation
    (cond
     (addresses
      (list (format nil "~A~%~{  ~{~A~}~^~%~}" owner 
                    (broadcast addresses '=summary))))
     ((list (format nil "~A - Adresse inconnue." owner))))))

#|
? (send '$E-PERSON.2 '=get-address)
("Barthès: Jean-Paul
       14, Allée de la Tilloye
     60200 Compiègne
     (France)
       Université de Technologie de Compiègne
      Centre de Recherche de Royallieu
      Departement de Génie Informatique
      UMR CNRS 6599 HEUDIASYC
     60206 Compiègne cedex
     ")
|#
#|
;;;---------------------------------------- =get-definition-summary (ORGANIZATION)

(definstmethod =get-definition-summary ORGANIZATION ()
  `( 
    ;; this is to get the name in the right language
    ,(car (send (car (moss::%type-of *self*)) '=get-name))
    (,(car
       (send 
        ;(car (moss::%get-prop-id-from-name-and-class-ref 
        ;      'has-name "organization"))
        (moss::%%get-id "nom" :prop :class-ref "organisation")
        '=get-name))
     ,@(HAS-NAME))
    (,(car
       (send 
        ;(car 
        ; (moss::%get-prop-id-from-name-and-class-ref 'has-acronym "organization"))
        (moss::%%get-id "sigle" :prop :class-ref "organisation")
        '=get-name))
     ,@(HAS-ACRONYM))))
|#

#|
;;;---------------------------------------------- =get-definition-summary (PERSON)

(definstmethod =get-definition-summary PERSON ()
  `( 
    ;; this is to get the name in the right language
    ,(car (send (car (moss::%type-of *self*)) '=get-name))
    (,(car
       (send 
        ;(car (moss::%get-prop-id-from-name-and-class-ref 'has-name "personne"))
        (moss::%%get-id "nom" :prop :class-ref "personne")
        '=get-name))
     ,@(HAS-NAME))
    (,(car
       (send 
        ;(car 
        ; (moss::%get-prop-id-from-name-and-class-ref 'has-first-name "personne"))
        (moss::%%get-id "prénom" :prop :class-ref "personne")
        '=get-name))
     ,@(HAS-FIRST-NAME))))
|#

#|
? (send '$E-PERSON.2 '=get-definition-summary)
|#
;;;------------------------------------------------------ =summary (EMAIL-ADDRESS)

(definstmethod =summary EMAIL-ADDRESS ()
  (list (format nil "~{~A~^, ~}" (send *self* '=get 'HAS-E-ADDRESS))))


#|
? (send '$E-EMAIL-ADDRESS.1 '=summary)
("barthes@utc.fr")
|#
;;;------------------------------------------------------------ =summary (COUNTRY)

(definstmethod =summary COUNTRY ()
  (list (mln::get-canonical-name (car (has-name)))))

#|
? (send '$E-COUNTRY.1 '=summary)
("Brésil")
|#
;;;------------------------------------------------------- =summary (HOME-ADDRESS)

(definstmethod =summary HOME-ADDRESS ()
  (list (moss::%pformat "~{~A~^~&~}, ~{~A~^ ~} ~{~A~^ ~}, ~{~A~^ ~}"
                        (cdr (send *self* '=make-print-string))
                        "street" "zip" "town" "country"
                        )))

#|
? (send '$E-HOME-ADDRESS.1 '=summary)
("14, Allée de la Tilloye, 60200 Compiègne, (France)")
|#
;;;------------------------------------------------------- =summary (ORGANIZATION)

(definstmethod =summary ORGANIZATION ()
  (list (format nil "~{~A~}" (or (HAS-ACRONYM) (HAS-NAME)))))

#|
? (send '$E-ORGANIZATION.1 '=summary)
("DGA")
|#
;;;------------------------------------------------------------- =summary (PERSON)

(definstmethod =summary PERSON ()
  (list (format nil "~{~A~^, ~}: ~{~A~^, ~}" (HAS-NAME) (HAS-FIRST-NAME))))

#|
? (send '$E-PERSON.1 '=summary)
("de Azevedo: Hilton")
|#
;;;-------------------------------------------------------------- =summary (PHONE)

(definstmethod =summary PHONE ()
  (list (format nil "~{~A~^, ~}" (HAS-NUMBER))))

#|
? (send '$E-HOME-PHONE.1 '=summary)
("+33 (0)3 44 23 31 37")
|#
;;;----------------------------------------------------- =summary (POSTAL-ADDRESS)

(definstmethod =summary POSTAL-ADDRESS ()
  (list (moss::%pformat "~{~A~^~&~}, ~{~A~^ ~} ~{~A~^ ~}~{~^, ~A ~}"
                        (cdr (send *self* '=make-print-string))
                        "street" "zip" "town" "country" 
                        )))

#|
? (send '$E-POSTAL-ADDRESS.1 '=summary)
("PUC, rua Immaculada Concepçaõ,  Curitiba, Parana, (Brésil)")
|#
;;;-------------------------------------------------------- =summary (WEB-ADDRESS)

(definstmethod =summary WEB-ADDRESS ()
  (list (format nil "~{~A~^, ~}" (send *self* '=get 'HAS-URL))))

#|
? (send '$E-WEB-ADDRESS.1 '=summary)
("http://www.utc.fr/~barthes")
|#

;;;===============================================================================
;;;===============================================================================
;;;
;;;                                INDIVIDUALS
;;;
;;;===============================================================================
;;;===============================================================================


;;;===================================================================== ADDRESSES 

;;;---------------------------------------------------------------- POSTAL ADDRESS

(defindividual "home address"
  (:doc :en "The address of Jean-Paul Barthès."
        :fr "L'adresse de Jean-Paul Barthès."
        )
  ("street" "14, Allée de la Tilloye")
  ("town" "Compiègne")
  ("country" _country-france)
  ("zip" "60200")
  (:var _jpb-addr))

(defindividual "postal address"
  (:doc :en "The address of PUC" :fr "L'adresse de la PUC")
  ("street" "PUC, rua Immaculada Concepçaõ")
  ("town" "Curitiba, Parana")
  ("country" _country-Brasil)
  (:var _puc-addr)
  )

(defindividual "postal address"
  (:doc :en "The address of CEFET" :fr "L'adresse du CEFET")
  ("street" "CEFET")
  ("town" "Curitiba, Parana")
  ("country" _country-brasil)
  (:var _cefet-addr)
  )

(defindividual "postal address"
  (:doc :en "The address of Cinvestav" :fr "L'adresse de Cinvestav")
  ("street" "CINVESTAV")
  ("town" "Guadelajara, Jalisco")
  ("country" _country-mexico)
  (:var _cinvestav-addr)
  )

(defindividual "postal address"
  (:doc :en "The address of CIT" :fr "L'adresse de CIT")
  ("town" "Chiba")
  ("country" _country-japan)
  (:var _cit-addr)
  )

(defindividual "postal address"
  (:doc :en "The address of TECPAR" :fr "L'adresse du TECPAR")
  ("street" "TECPAR")
  ("town" "Curitiba, Parana")
  ("country" _country-brasil)
  (:var _tecpar-addr)
  )

(defindividual "postal address"
  (:doc :en "The address of UTC" :fr "L'adresse de l'UTC")
  ("street" "rue Roger Couttolenc")
  ("town" "Compiègne")
  ("zip" "60200")
  (:var _utc-addr)
  )

(defindividual "office address"
  (:doc :en "The address of UTC Research Center"
        :fr "L'adresse du Centre de recherches de Royllieu")
  ("street" "Centre de Recherche de Royallieu" "BP 20529")
  ("town" "Compiègne cedex")
  ("zip" "60205")
  ("country" _country-france)
  (:var _utc-crr-addr)
  )

;;;======================================================================== PEOPLE 

(defindividual "person"
  ("name" "de Azevedo")
  ("first name" "Hilton")
  ("address" _cefet-addr)
  (:doc :en "Dr. Hilton de Azevedo is working at CEFET."
        :fr "Le Dr. Hilton de Azevedo est professeur au CEFET.")
  (:var _eda)
  )

(defindividual "person"
  ("name" "Barthès")
  ("first name" "Jean-Paul")
  ("address" _jpb-addr
   (:new "office address"
         ("street " "Université de Technologie de Compiègne"
          "Centre de Recherche de Royallieu"
          "Departement de Génie Informatique"
          "UMR CNRS 6599 HEUDIASYC")
         ("zip" "60206")
         ("city" "Compiègne cedex")))
  ("email" (:new "email"
                 ("e-address" "barthes@utc.fr")))
  ("web page" (:new "web page"
                    ("URL" "http://www.utc.fr/~barthes")))
  ("phone" 
   (:new  "home phone"
          ("number" "+33 (0)3 44 23 31 37")
          (:var _jpb-home-phone))
   (:new "office phone"
         ("number" "+33 (0)3 44 23 44 66"))
   (:new "cell phone"
         ("number" "+33 (0)6 80 45 32 67")))
  (:var _jpb)
  (:doc :en "Jean-Paul Barthès is a professor at University of ~
             Technology of Compiègne."
        :fr "Jean-Paul barthès est professeur à l'UTC.")
  )

(defindividual "person"
  ("name" "Barthès" "Barthès-Biesel" )
  ("first name" "Dominique")
  ("address" _jpb-addr
   (:new "office address"
         ("street" "Université de Technologie de Compiègne"
          "Centre de Recherche de Royallieu"
          "Département de Génie Biomédical")
         ("zip" "60206")
         ("city" "Compiègne cedex")))
  ("email" (:new "email"
                 ("e-address" "dbb@utc.fr")))
  ("phone" _jpb-home-phone 
   (:new "office phone"
         ("number" "+33 (0)3 44 23 43 93"))
   (:new "cell phone"
         ("number" "+33 (0)6 81 24 46 66")))
  (:var _dbb)
  (:doc :en 
        "Dominique Barthès Biesel is a professor at University of Technology ~
         of Compiègne."
        :fr "Dominique Barthès-Biesel est professeur à l'UTC")
  )

(defindividual "person"
  ("name" "Barthès")
  ("first name" "Camille")
  ("email" (:new "email"
                 ("e-address" "kangming421@126.com")))
  ("phone" 
   (:new "home phone"
         ("number" "+86 571 8701 0782"))
   (:new "cell phone"
         ("number" "+86 134 5678 3173")))
  (:var _cxb)
  (:doc :en "Camille Barthès is a Chinese coolie living currently at Qingdao."
        :fr "Camille Barthès est un coolie chinois qui habite Qingdao.")
  )

(defindividual "person"
  ("name" "Bonnifait")
  ("first name" "Philippe")
  ("employer" "UTC")
  (:doc :fr "Philippe Bonnifait est professeur à l'UTC")
  )

(defindividual "person"
  ("name" "Bouabdallah")
  ("first name" "Madjid")
  ("address" _utc-crr-addr)
  (:doc :fr "Madjid Bouabdallah est professeur à l'UTC et chercheur au laboratoire HEUDIASYC.")
  )

(defindividual "person"
  ("name" "Charara")
  ("first name" "Ali")
  ("address" _utc-crr-addr)
  (:doc :fr "Ali Charara est le directeur du laboratoire HEUDIASYC à l'UTC")
  )

(defindividual "student"
  ("name" "Chen")
  ("first name" "Kejia")
  (:var _kc)
  (:doc :en "Kejia Chen was a PhD student at UTC and is now teaching at Nanjing."
        :fr "Kejia Chen était doctorante à l'UTC et est MC à Nanjing.")
  ("address" _utc-crr-addr)
  )

(defindividual "person"
  ("name" "Denoeux")
  ("first name" "Thierry")
  ("address" _utc-crr-addr)
  (:doc :fr "Thierry Denoeux est professeur à l'UTC et directeur adjoint du laboratoire HEUDIASYC.")
  )

(defindividual "person"
  ("name" "Dubuisson")
  ("first name" "Bernard")
  ("address" _utc-crr-addr)
  (:doc :fr "Bernard Dubuisson est professeur à l'UTC et conseiller à la DGA.")
  )

(defindividual "person"
  ("name" "Enembreck")
  ("first name" "Fabricio")
  ("address" _puc-addr)
  (:doc :en "Dr. Fabricio Enembreck is working at PUC."
        :fr "Le Dr. Fabricio Enembreck est professeur à la PUC.")
  (:var _fe)
  )

(defindividual "person"
  ("name" "Fontaine")
  ("first name" "Dominique")
  (:var _df)
  (:doc :fr "Dominique Fontaine est maître de conférences at UTC.")
  ("address" _utc-crr-addr)
  )

(defindividual "person"
  ("name" "Lourdeaux")
  ("first name" "Domitile")
  ("address" _utc-crr-addr)
  (:doc :fr "Domitile Lourdeaux est enseignant-chercheur à l'UTC")
  )

(defindividual "person"
  ("name" "Lozano")
  ("first name" "Rogelio")
  ("address" _utc-crr-addr)
  (:doc :fr "Rogelio Lozano est chercheur dans le laboratoire HEUDIASYC et directeur 
de l'UMI franco-mexicaine.")
  )

(defindividual "person"
  ("nom" "Manabe")
  ("first name" "Yusuke")
  (:doc :en "Yusuke Manabe is an assistant professor at CIT.")
  ("phone" (:new "cell phone" ("number" "+81 12 34 56 78")))
  )

(defindividual "person"
  ("nom" "Mathieu")
  ("first name" "Philippe")
  (:doc :fr "Philippe Mathieu est professeur d'informatique à Lille 1.")
  (:var _pm)
  )

(defindividual "person"
  ("name" "Paraiso")
  ("first name" "Emerson")
  ("address" _puc-addr)
  (:doc :en "Dr. Emerson Paraiso is working at PUC."
        :fr "Le docteur Emerson Paraiso est professeur à la PUC")
  (:var _ep)
  )

(defindividual "person"
  ("name" "Real")
  ("trade" "taxi")
  ("phone" (:new "cell phone" ("number" "+33 (0)6 07 54 02 27")))
  (:doc :en "Real had a deal with UTC to drive persons at a decent cost ~
             but unfortunately died in 2008.")
  )

(defindividual "person"
  ("name" "Stephan")
  ("first name" "Ronan")
  ("phone" (:new "cell phone" ("number" "+33 (0)3 44 23 44 23")))
  ("address" _utc-addr)
  (:doc :en "Stephan is the president of UTC."
        :fr "Ronan Stephan est le président de l'UTC.")
  (:var _rs)
  )

(defindividual "person"
  ("name" "Ramos")
  ("first name" "Milton")
  ("address" _tecpar-addr)
  (:doc :en "Dr. Milton Ramos is working at TECPAR."
        :fr "Le Dr. Milton Ramos est responsable des activités IA au TECPAR.")
  (:var _mr)
  )

(defindividual "person"
  ("name" "Ramos")
  ("first name" "Feliz")
  ("address" _cinvestav-addr)
  (:doc :en "Dr. Felix Ramos is working at CINVESTAV.")
  (:var _fr)
  )

(defindividual "person"
  ("name" "Scalabrin")
  ("first name" "Edson")
  ("address" _puc-addr)
  (:doc :en "Dr. Edson Scalabrin is working at PUC"
        :fr "Le Dr. Edson Scalabrin est professeur à la PUC.")
  (:var _es)
  )

(defindividual "person"
  ("name" "Sugawara")
  ("first name" " ")
  ("address" _cit-addr)
  (:doc :en "Prof. Sugawara is working at CIT in Japan."
        :fr "Le Prof. Sugawara est professeur au CIT.")
  (:var _hs)
  )

(defindividual "person"
  ("name" "Tacla")
  ("first name" "Cesar")
  ("address" _cefet-addr)
  (:doc :en "Dr. Edson Scalabrin is working at PUC")
  (:var _es)
  )

;;;---------- students

(defindividual "student"
  ("name" "Sato")
  ("first name" "Gilson")
  ("phone" (:new "office phone"
                 ("number" "+33 (0)3 44 23 44 23 ext: 4202")))
  ("address" _utc-crr-addr)
  ("school" _UTC)
  (:doc :fr "Gilson Sato était doctorant à l'UTC.")
  (:var _gs)
  )

;;;============================================================ PUBLISHED MATERIAL


;;;================================================================= ORGANIZATIONS 

(defindividual "organization"
  ("name" "Délégation Générale pour l'Armement")
  ("acronym" "DGA")
  ("division"
   (:new "organization"
         ("name" "direction des systèmes de forces et des stratégies industrielle, 
technologique et de coopération.")
         ("acronym" "D4S"))
   (:new "organization"
         ("acronym" "MRIS")
         ("name" "Mission pour la Recherche et l'Innovation Scientifique"))
   )
  (:doc :fr "Maître d'ouvrage des programmes d'armement, la DGA est responsable 
de la conception, de l'acquisition et de l'évaluation des systèmes qui équipent 
les forces armées. Son action couvre toute la durée de vie de ces programmes.")
  )

(defindividual "university"
  ("name" "Universidade Pontifical do Parana")
  ("acronym" "PUC")
  ("address" (:new "postal address"
                   (:doc :en "The address of PUC")
                   ("street" "rua Immaculata Conceiçaõ")
                   ("town" "Curitiba, Parana")
                   ("country" _country-brasil)))
  (:var _PUC)
  )

(defindividual "university"
  ("name" "Université de Technologie de Compiègne")
  ("acronym" "UTC")
  ("address" (:new "postal address"
                   (:doc :en "The address of UTC")
                   ("street" "rue Roger Couttolenc")
                   ("town" "Compiègne")
                   ("zip" "60200")))
  ("president" _rs)
  ("phone" (:new "office phone"
                 ("number" "+33 3 44 32 44 23")))
  (:var _UTC)
  )

(defindividual "organization"
  ("name" "Centre National pour la Recherche Scientifique")
  ("acronym" "CNRS")
  (:var _cnrs)
  )

(defindividual "non profit organization"
  ("name" "Institut International pour l'Intelligence Artificielle")
  ("acronym" "IIIA")
  ("address" (:new "postal address" 
                   ("street" "Centre de Transfert" "66 avenue de Landshut")
                   ("town" "Compiègne")("zip" "60200")))
  ("phone" (:new "cell phone"
                 ("number" "+33 6 80 45 32 67")))
  ("president" _jpb)
  (:var _IIIA)
  )

;;;====================================================================== MEETINGS 

(defindividual "manifestation"
  ("nom" "Journées Francophones pour les Systèmes Multi-Agents")
  ("sigle" "JFSMA")
  ("président du comité de programme" _pm)
  ("adresse"
   (:new "adresse postale"
         ("rue" "Hotel Terminus")
         ("ville" "Carcassonne")))
  ("time" "octobre")
  (:doc :fr "Les Journées Francophones pour les Systèmes Multi-Agents sont une ~
             manifestation annuelle regroupant des chercheurs de langue française.")
  (:var _jfsma))

;;;=================================================================== TERRITORIES 

(defindividual "country"
  ("name" (:en "Brasil" :fr "Brésil"))
  (:var _country-brasil)
  )

(defindividual "country"
  ("name" (:en "France" :fr "France"))
  (:var _country-france)
  )

(defindividual "country"
  ("name" (:en "Japan" :fr "Japon"))
  (:var _country-japan)
  )

(defindividual "country"
  ("name" (:en "Mexico" :fr "Mexique"))
  (:var _country-mexico)
  )

;;;=============================================================================== 

:EOF
