﻿;;;-*- Mode: Lisp; Package: "DOCTOR" -*-
;;;===============================================================================
;;;11/04/16
;;;                               AGENT DOCTOR
;;;
;;;===============================================================================


#|
2011
 0414 creating the DOCTOR agent
|#

;;;===============================================================================
;;; 
;;;                         defining agent package 
;;;
;;;===============================================================================
	 
(defpackage :DOCTOR (:use :moss :omas :cl #+MCL :ccl))
(in-package :DOCTOR)

;;;===============================================================================
;;; 
;;;                              defining the agent 
;;;
;;;===============================================================================

(omas::defassistant :DOCTOR :language :en :show-dialog t)

The DOCTOR window will be used to start or control the PATIENT dialog

;;;===============================================================================
;;; 
;;;                         service macros and functions 
;;; Place here the macros and functions used by the skills and goals
;;;===============================================================================



;;; ================================= globals ====================================
;;; Globals  can be used within the agent space to simplify programming, although
;;; it is better to use the agent memory.


;;;===============================================================================
;;; 
;;;                                    SKILLS 
;;; 
;;;===============================================================================
;;; 
;;; ======================================================================== skill
;;;                                CONVERSATION
;;; ==============================================================================
;;; DOCTOR starts a conversation by sending a message
;;; each conversation turn is guided by the rules
;;; Rules are partitioned according to the topic being discussed
;;; Each conversation turn is a request sent to the PATIENT
;;; If the PATIENT does not answer fast enough, then the reuest is canaceled and
;;; a new request is sent

(defskill :conversation :DOCTOR
  :static-fcn static-conversation
  :dynamic-fcn dynamic-conversation
  :timeout-handler timeout-handler-conversation
  )
     
(defun static-conversation (agent message)
  "starts the conversation by sending Hello"
  (declare (ignore message))
  (send-subtask :from :DOCTOR :to :patient :action :ask-question
          :args '(((:data . "Hello!")(:language . :en)))
		  :timeout 10)
  (remember agent 1 :turn)
  (static-exit agent :done))
  
(defun dynamic-conversation (agent message answer)
  "we get something from the patient and run it through the ELIZA-like
   dialog"
  (let ((input (cdr (assoc :data answer)))
        next msg)
	(setq next (moss::moss-eliza input rules))
    ;; ship a message back to the patient
	(setq msg (make-instance 'omas::message :from :DOCTOR 
	             :to (omas::from! message) :type :inform :action :say
				 :args `(((:data . ,next)))))
	(send-message msg)
	;; we do not exit the task but exit the function
	))
   
   
;;; ======================================================================== skill
;;;                                     NLP
;;; ==============================================================================

(defskill :NLP :DOCTOR
  :static-fcn static-NLP
  ;:time-limit-fcn time-limit-NLP
  )
     
;;; Keep only those functions that are useful for your application
;;; agent and message are variables set by OMAS
;;; agent is the current agent
;;; message is the message that trigerred the function  

(defun static-NLP (agent message args)
  "Analyzes a list of input words using rules and sends back the answer.
Arguments:
   agent: agent
   message: incoming message
   args: e.g. ((:data \"I\" \"remember\" \"my\" \"visit\")(:language :en))
Return:
   appropriate answer (a string)."
  (declare (ignore message))
  (let ((input (cdr (assoc :data args)))
        (rules (recall agent :palace))
		answer msg)
    (format t "~%; static-NLP /input: ~S" input)
	;(format t "~%; static-NLP /rules: ~S" rules)
    (setq answer (moss::moss-eliza input rules))
	;; ship a message back to the patient
	(setq msg (make-instance 'omas::message :from :DOCTOR 
	             :to (omas::from! message) :type :inform :action :say
				 :args (list answer)))
	(send-message msg)
	(sleep .1)
    (static-exit agent answer)))

#|  
(static-NLP SA_DOCTOR
      (make-instance 'omas::message :from :PATIENT :to :DOCTOR
	      :action :NLP 
		  :args '(((:data "do" "you" "remember" "the" "palace")
		           (:language . :en))))
	  '((:data "do" "you" "remember" "the" "palace")
		          (:language . :en))
	  )
|#


;;; ==============================================================================
;;;                                 Skill  XXX
;;; ==============================================================================
#|
(defskill :XXX :DOCTOR
  :static-fcn static-XXX
  :dynamic-fcn dynamic-XXX
  :acknowledge-fcn acknowledge-XXX
  :bid-cost-fcn bid-cost-XXX
  :bid-quality-fcn bid-quality-XXX
  :bid-start-time-fcn bid-start-time-XXX
  :how-long-fcn how-long-XXX
  :preconditions preconditions-XXX
  :select-best-answer-fcn select-best-answer-XXX
  :time-limit-fcn time-limit-XXX
  :timeout-handler timeout-handler-XXX
  )
     
;;; Keep only those functions that are useful for your application
;;; agent and message are variables set by OMAS
;;; agent is the current agent
;;; message is the message that trigerred the function  

(defun static-xxx (agent message <args>)
  "documentation"
  (static-exit agent <result>))

(defun dynamic-xxx (agent message <args>)
  "documentation"
  (dynamic-exit agent <result>))

(defun acknnowledge-xxx (agent message <args>)
    "documentation"
  )

;;; <arg-list> is the list of args contained in the call-for-bids message, i.e. 
;;; the args corresponding to the task to be done

(defun bid-cost-fcn bid-cost-xxx (agent <arg-list>)
    "documentation"
  <return a list (<cost> <rigidity>)>)

(defun bid-quality-xxx (agent <arg-list>)
    "documentation"
  )

(defun bid-start-time-xxx (agent <arg-list>)
    "documentation"
  )

(defun how-long-xxx (agent <arg-list>)
    "documentation"
  )
  
(defun preconditions-xxx (agent message <args>)
    "documentation"
  )

(defun select-best-answer-xxx (agent answer-message-list)
    "documentation"
  )
  
(defun time-limit-xxx (agent message message)
    "documentation"
  )

(defun timeout-handler-xxx (agent message)
    "documentation"
  )
|#

;;;===============================================================================
;;; 
;;;                               initial conditions 
;;;
;;;===============================================================================

;;; insert here whatever initial conditions need to be provided in the agent memory
;;; Ex. (deffact SA_book-seller-1 0 :money)

#|
(deffact SA_DOCTOR <any value> <key>)
|#
(deffact PA_DOCTOR 
  ( 
    (("how" "are" "you" (?* ?x))
     "Very well thank you."
     "Really does my health concern you? I am flattered.")

	(((?* ?x) "sorry" (?* ?y))
     "Please don't apologize"
     "Apologies are not necessary"
     "What feelings do you have when you apologize?")
    (((?* ?x) "I" "remember" (?* ?y))
     "Do you often think of ?y"
     "Does thinking of ?y bring anything else to mind?"
     "What else do you remember?"
     "Why do you recall ?y right now?"
     "What in the present situation reminds you of ?y ?"
     "What is the connection between me and ?y ?")
    (((?* ?x) "do" "you" "remember" (?* ?y))
     "Did you think I would forget ?y ?"
     "Why do you think I should recall ?y by now ?"
     "What about ?y ?"
     "You mentined ?y ?")
	)
    :palace)
	

:EOF