﻿;;;-*- Mode: Lisp; Package: "PROJECT" -*-
;;;============================================================================= 
;;;21/11/2013
;;;                              PROJECT ONTOLOGY                               
;;;
;;;============================================================================= 
#|
2013
 1121 Creation based on project-ontology.lisp from HDSRI project.
|#

(in-package "PROJECT")

(defontology
  (:title (:EN "SA_PROJECT MOSS"))
  (:version "8.0.0")
  (:language :ALL)
  )


;;;============================================================================= 
;;;
;;;                                  CONCEPTS                                   
;;;
;;;============================================================================= 

;;;============================================================================= 
;;;                             CONTRIBUTION ÉQUIPE                             
;;;============================================================================= 

(defconcept (:EN "Team funding" :FR "Contribution équipe")
  (:ATT (:EN "amount" :FR "montant") (:MIN 1) (:MAX 1))
  (:REL (:EN "team" :FR "équipe") (:TO "Équipe") (:MIN 1) (:MAX 1))
  (:doc :EN "Amount of money the team gives to the project" :FR "Financement mis par l'équipe dans le projet"))

;;;============================================================================= 
;;;                                   DOMAINE                                   
;;;============================================================================= 

(defconcept (:EN "research domain" :FR "domaine")
  (:ATT (:EN "topic" :EN "sujet") (:ENTRY)))

;;;============================================================================= 
;;;                             FINANCEMENT ANNUEL                              
;;;============================================================================= 

(defconcept (:EN "Annual funding" :FR "Financement annuel")
  (:ATT (:EN "year" :FR "année") (:MIN 1) (:MAX 1))
  (:ATT (:EN "amount" :FR "montant"))
  (:doc :EN "Amount of funding this year" :FR "Financement de l'année"))

;;;============================================================================= 
;;;                             IMPLICATION ÉQUIPE                              
;;;============================================================================= 

(defconcept (:EN "Team work" :FR "Implication équipe")
  (:ATT (:EN "percentage" :FR "pourcentage") (:MIN 1) (:MAX 1))
  (:REL (:EN "team" :FR "équipe") (:TO "Équipe") (:MIN 1) (:MAX 1))
  (:doc :EN "Amount of time the team gives to the project" :FR "Pourcentage du temps mis par l'équipe dans le projet"))

;;;============================================================================= 
;;;                                ORGANISATION                                 
;;;============================================================================= 

(defconcept (:EN "organization" :FR "organisation")
  (:ATT (:EN "name" :FR "nom") (:ENTRY))
  (:ATT (:EN "acronym" :FR "sigle") (:ENTRY))
  (:ATT (:EN "email" :FR "email"))
  (:doc :EN "An ORGANIZATION is a social structure private or public that has some ~
             social goals." :FR "Une ORGANISATION est une structure sociale privée ou publique qui ~
             poursuit un but social."))

;;;============================================================================= 
;;;                                    PAYS                                     
;;;============================================================================= 

(defconcept (:EN "country" :FR "pays")
  (:IS-A "territoire")
  (:doc :EN "A COUNTRY is a territory..." :FR "Un PAYS est un territoire habité par une collectivité et constituant ~
             une réalité géographique dénommée."))

;;;============================================================================= 
;;;                                  PERSONNE                                   
;;;============================================================================= 

(defconcept (:EN "person" :FR "personne")
  (:ATT (:EN "id" :FR "id"))
  (:ATT (:EN "name" :FR "nom") (:ENTRY))
  (:ATT (:EN "first-name" :FR "prénom") (:ENTRY))
  (:ATT (:EN "first-name initials" :FR "initiales du prénom"))
  (:ATT (:EN "initials" :FR "initiales"))
  (:ATT (:EN "email" :FR "email"))
  (:doc :EN "A PERSON is a human being member of a project." :FR "Une PERSONNE est un être humain qui participe à un projet."))

(defownmethod =if-needed 
  ("id" "MOSS PROPERTY-NAME" "MOSS ATTRIBUTE" :class-ref "person") 
  (obj-id) 
  (let ((id (send obj-id '=get "moss-identifier")))
    (list (concatenate 'string (package-name *package*) "/" 
	(symbol-name(car id))))))  
  
  
;;;============================================================================= 
;;;                                   PROJET                                    
;;;============================================================================= 

(defconcept (:EN "Project; Projects" :FR "Projet; Projets")
  (:ATT (:EN "id" :FR "id"))
  (:ATT (:EN "title" :FR "titre; nom projet"))
  (:ATT (:EN "abstract" :FR "résumé; descriptif"))
  (:ATT (:EN "acronym" :FR "sigle") (:MIN 1) (:MAX 1) (:ENTRY))
  (:ATT (:EN "budget account" :FR "unité budget"))
  (:ATT (:EN "platforms" :FR "plateformes/ démos"))
  (:ATT (:EN "amount of man-months" :FR "(H/mois) perm."))
  (:ATT (:EN "submission date" :FR "date de dépôt"))
  (:ATT (:EN "start" :FR "début") (:ENTRY))
  (:ATT (:EN "start date" :FR "date de début; date début"))
  (:ATT (:EN "end" :FR "fin") (:ENTRY))
  (:ATT (:EN "end date" :FR "date de fin; date fin"))
  (:ATT (:EN "duration" :FR "durée; durée en mois"))
  (:ATT
 (:EN "type of contract; project type" :FR
  "forme de contrat; type de projet"))
  (:ATT (:EN "total cost" :FR "financement"))
  (:ATT (:EN "nb of projects; projet" :FR "nb de projets"))
  (:ATT (:EN "nb of theses" :FR "nb de thèses; thèse"))
  (:ATT (:EN "partner financing" :FR "aide totale partenaires"))
  (:ATT (:EN "HDS financing; utc grant" :FR "aide totale heudiasyc H.T"))
  (:ATT (:EN "check" :FR "vérif."))
  (:ATT (:EN "comment" :FR "commentaire; remarques"))
  (:ATT (:EN "archived" :FR "archivé"))
  (:ATT (:EN "web site" :FR "site web"))
  (:ATT (:EN "status" :FR "état") (:ENTRY))
  (:REL (:EN "country" :FR "pays") (:TO "pays"))
  (:REL (:EN "team" :FR "équipe") (:TO "Implication équipe"))
  (:REL
 (:EN "financing source; funding agency" :FR
  "origine du crédit; financeur")
 (:TO "organisation"))
  (:REL (:EN "scientific leader" :FR "responsable scientifique")
 (:TO "personne"))
  (:REL (:EN "permanent members" :FR "membres permanents")
 (:TO "personne"))
  (:REL (:EN "members" :FR "participants") (:TO "personne"))
  (:REL (:EN "non permanent members" :FR "non permanents")
 (:TO "personne"))
  (:REL (:EN "partners;partner" :FR "partenaires") (:TO "organisation"))
  (:REL (:EN "coordinator" :FR "coordinateur") (:TO "personne"))
  (:REL (:EN "managing partner" :FR "partenaire gestion")
 (:TO "organisation"))
  (:REL (:EN "team funding" :FR "contribution équipe")
 (:TO "Contribution équipe"))
  (:REL (:EN "annual cost" :FR "financement annuel")
 (:TO "Financement annuel"))
  (:REL (:EN "UTC coordinator" :FR "correspondant UTC") (:TO "personne"))
  (:REL (:EN "domain" :FR "domaine") (:TO "domaine"))
  (:doc :EN "A PROJECT is a research activity that may or may nt be funded." :FR "Un PROJET est une activité de recherche financée ou non."))

(defownmethod =if-needed 
  ("id" "MOSS PROPERTY-NAME" "MOSS ATTRIBUTE" :class-ref "Project") 
  (obj-id) 
  (let ((id (send obj-id '=get "moss-identifier")))
    (list (concatenate 'string (package-name *package*) "/" 
	(symbol-name(car id))))))
  
;;;============================================================================= 
;;;                                 TERRITOIRE                                  
;;;============================================================================= 

(defconcept (:EN "territory" :FR "territoire")
  (:ATT (:EN "name" :FR "nom") (:ENTRY)))

;;;============================================================================= 
;;;                                    THÈSE                                    
;;;============================================================================= 

(defconcept (:EN "Thesis" :FR "Thèse")
  (:IS-A "Projet")
  (:doc :EN "A THESIS has roughly the same properties as a project since, most of ~
            the time it is associated with a project." :FR "Une THÈSE a globalement les mêmes propriétés qu'un projet, car en ~
		    général ell est associée à un projet."))

;;;============================================================================= 
;;;                                   ÉQUIPE                                    
;;;============================================================================= 

(defconcept (:EN "Team" :FR "Équipe")
  (:ATT (:EN "name" :FR "nom"))
  (:ATT (:EN "acronym" :FR "sigle") (:ENTRY))
  (:REL (:EN "member" :FR "membre") (:TO "personne"))
  (:doc :EN "Research Team" :FR "Équipe de recherche"))
  

;;;============================================================================= 
;;;
;;;                                  FUNCTIONS                                  
;;;
;;;============================================================================= 

;;;------------------------------------------------------------- F_%INCLUDE-NAME

(DEFFUNCTION %INCLUDE-NAME (PROP VAL PROP-LIST)
             "merges val with the value associated with prop in the prop-list.
Arguments:
   prop: e.g. \"rue\"
   val: e.g. \"UTC\"
   prop-list: an a-list
Return:
   the modified prop-list."
             (COND ((NULL PROP-LIST) (LIST (LIST PROP VAL)))
                   ((STRING-EQUAL PROP (CAAR PROP-LIST))
                    `((,PROP
                       ,(CONCATENATE 'STRING VAL ", "
                                     (CADAR PROP-LIST)))
                      ,@(CDR PROP-LIST)))
                   (T
                    (CONS (CAR PROP-LIST)
                          (%INCLUDE-NAME PROP VAL (CDR PROP-LIST))))))

;;;-------------------------------------------------------------------- F_EXTIFF

(DEFFUNCTION EXTIFF (NAME-STRING)
             (LET (RESULT POS)
               (WHEN (AND NAME-STRING (STRINGP NAME-STRING))
                 (SETQ NAME-STRING
                       (STRING-UPCASE
                          (STRING-TRIM '(#\Space) NAME-STRING)))
                 (LOOP (UNLESS NAME-STRING
                         (RETURN (FORMAT
                                  NIL
                                  "~{~A.~^-~}"
                                  (REVERSE RESULT))))
                       (PUSH (SUBSEQ NAME-STRING 0 1) RESULT)
                       (SETQ POS (POSITION #\- NAME-STRING))
                       (SETQ NAME-STRING
                             (IF POS (SUBSEQ NAME-STRING (1+ POS))))))))

;;;---------------------------------------------------------- F_EXTRACT-INITIALS

(DEFFUNCTION EXTRACT-INITIALS (FIRST-NAME-STRING NAME-STRING)
             (LET (RESULT POS TEXT)
               (WHEN (AND (STRINGP FIRST-NAME-STRING)
                          (STRINGP NAME-STRING))
                 (SETQ TEXT
                       (CONCATENATE 'STRING FIRST-NAME-STRING " "
                                    (STRING-TRIM
                                     '(#\Space)
                                     NAME-STRING)))
                 (SETQ TEXT
                       (SUBSTITUTE #\Space #\-
                                   (STRING-UPCASE
                                    (STRING-TRIM '(#\Space) TEXT))))
                 (LOOP (UNLESS TEXT (RETURN))
                       (PUSH (SUBSEQ TEXT 0 1) RESULT)
                       (SETQ POS
                             (OR (POSITION #\- TEXT)
                                 (POSITION #\Space TEXT)))
                       (SETQ TEXT
                             (IF POS
                                 (STRING-TRIM
                                  '(#\Space)
                                  (SUBSEQ TEXT (1+ POS)))))))
               (IF RESULT (FORMAT NIL "~{~A~}" (REVERSE RESULT)))))

;;;------------------------------------------ F_EXTRACT-INITIALS-FROM-FIRST-NAME

(DEFFUNCTION EXTRACT-INITIALS-FROM-FIRST-NAME (FIRST-NAME-LIST)
             (FORMAT NIL "~{~A~}" (MAPCAR #'EXTIFF FIRST-NAME-LIST)))
  
;;;============================================================================= 
;;;
;;;                                   METHODS                                   
;;;
;;;============================================================================= 

;;;------------------------------------------------------------------ =IF-NEEDED

(DEFOWNMETHOD =IF-NEEDED
              ("participants" "MOSS property name" "MOSS RELATION"
               :CLASS-REF "Projet")
              (OBJ-ID)
              (LET (PERSON-ID-LIST)
                (SETQ PERSON-ID-LIST
                      (APPEND (SEND OBJ-ID '=GET
                                    "responsable scientifique")
                              (SEND OBJ-ID '=GET "coordinateur")
                              (SEND OBJ-ID '=GET "membres permanents")
                              (SEND OBJ-ID '=GET "non permanents")))
                (SETQ PERSON-ID-LIST
                      (REMOVE-DUPLICATES PERSON-ID-LIST :FROM-END T))))

;;;------------------------------------------------------------------ =IF-NEEDED

(DEFOWNMETHOD =IF-NEEDED
              ("initiales du prénom" "MOSS property name"
               "MOSS ATTRIBUTE" :CLASS-REF "personne")
              (OBJ-ID)
              (LET ((FIRST-NAME (SEND OBJ-ID '=GET "prénom")))
                (IF FIRST-NAME
                    (LIST (EXTRACT-INITIALS-FROM-FIRST-NAME
                            FIRST-NAME)))))

;;;------------------------------------------------------------------ =IF-NEEDED

(DEFOWNMETHOD =IF-NEEDED
              ("initiales" "MOSS property name" "MOSS ATTRIBUTE"
               :CLASS-REF "personne")
              (OBJ-ID)
              (LET ((FIRST-NAME (SEND OBJ-ID '=GET "prénom"))
                    (NAME (SEND OBJ-ID '=GET "nom")))
                (SETQ NAME (IF NAME (FORMAT NIL "~{~A ~}" NAME) "")
                      FIRST-NAME
                      (IF FIRST-NAME
                          (FORMAT NIL "~{~A ~}" FIRST-NAME)
                        ""))
                (LIST (EXTRACT-INITIALS FIRST-NAME NAME))))

;;;---------------------------------------------- (CONTRIBUTION ÉQUIPE) =SUMMARY

(DEFINSTMETHOD =SUMMARY "Contribution équipe" NIL
               (LIST (FORMAT NIL "~{~A ~}: ~{~A~^ ~}"
                             (SEND (CAR (HAS-TEAM)) '=SUMMARY)
                             (HAS-AMOUNT))))

;;;---------------------------------------------------------- (DOMAINE) =SUMMARY

(DEFINSTMETHOD =SUMMARY "domaine" NIL
               (LIST (FORMAT NIL "~{~A~^ ~}" (OR (HAS-TOPIC)))))

;;;----------------------------------------------- (FINANCEMENT ANNUEL) =SUMMARY

(DEFINSTMETHOD =SUMMARY "Financement annuel" NIL
               (LIST (FORMAT NIL "~{~A ~}: ~{~A~^ ~}" (HAS-YEAR)
                             (HAS-AMOUNT))))

;;;----------------------------------------------- (IMPLICATION ÉQUIPE) =SUMMARY

(DEFINSTMETHOD =SUMMARY "Implication équipe" NIL
               (LIST (FORMAT NIL "~{~A ~}: ~A%"
                             (SEND (CAR (HAS-TEAM)) '=SUMMARY)
                             (CAR (HAS-PERCENTAGE)))))

;;;------------------------------------------------------- (OMAS-AGENT) =SUMMARY

(DEFINSTMETHOD =SUMMARY "OMAS-AGENT" NIL (SEND *SELF* '=GET "ag-name"))

;;;-------------------------------------------------------- (OMAS-GOAL) =SUMMARY

(DEFINSTMETHOD =SUMMARY "OMAS-GOAL" NIL (SEND *SELF* '=GET "gl-name"))

;;;------------------------------------------------------- (OMAS-SKILL) =SUMMARY

(DEFINSTMETHOD =SUMMARY "OMAS-SKILL" NIL (SEND *SELF* '=GET "SK-NAME"))

;;;----------------------------------------------------- (ORGANISATION) =SUMMARY

(DEFINSTMETHOD =SUMMARY "organisation" NIL
               (LIST (FORMAT NIL "~{~A~^ ~}"
                             (OR (HAS-ACRONYM) (HAS-NAME)))))

;;;------------------------------------------------------------- (PAYS) =SUMMARY

(DEFINSTMETHOD =SUMMARY "pays" NIL
               (LIST (MLN::GET-CANONICAL-NAME (CAR (HAS-NAME)))))

;;;--------------------------------------------------------- (PERSONNE) =SUMMARY

(DEFINSTMETHOD =SUMMARY "personne" NIL
               (LIST (FORMAT NIL "~{~A~^, ~}, ~{~A~^, ~}"
                             (OR (HAS-NAME) '("?"))
                             (OR (HAS-FIRST-NAME-INITIALS) '("?")))))

;;;----------------------------------------------------------- (PROJET) =SUMMARY

(DEFINSTMETHOD =SUMMARY "Projet" NIL
               "get a summary of the PROJECT object. Standard is a list containing a single ~
   string." (LIST (SEND *SELF* '=GET-PROJECT-STRING :NO-CR T)))

;;;------------------------------------------------------------ (THÈSE) =SUMMARY

(DEFINSTMETHOD =SUMMARY "Thèse" NIL
               " get a summary of the THESIS with the name of the student."
               (LIST (FORMAT NIL "Thèse ~{~A~}"
                             (SEND (CAR
                                    (SEND
                                     *SELF*
                                     '=GET
                                     "non permanents"))
                                   '=SUMMARY))))

;;;----------------------------------------------------------- (ÉQUIPE) =SUMMARY

(DEFINSTMETHOD =SUMMARY "Équipe" NIL (HAS-ACRONYM))

;;;============================================================================= 
;;;============================================================================= 
;;;
;;;                        INDIVIDUALS (Knowledge Base)                         
;;;
;;;============================================================================= 
;;;============================================================================= 

(DEFINDIVIDUAL "domaine" ("topic" "apprentissage"))

(DEFINDIVIDUAL "domaine" ("topic" "robotique"))

(DEFINDIVIDUAL "Financement annuel" ("année" "2011") ("montant" "2000")
               (:VAR _I-407))

(DEFINDIVIDUAL "Financement annuel" ("année" "2012") ("montant" "6000")
               (:VAR _I-408))

(DEFINDIVIDUAL "Financement annuel" ("année" "2013")
               ("montant" "12000") (:VAR _I-409))

(DEFINDIVIDUAL "Financement annuel" ("année" "2012")
               ("montant" "60000") (:VAR _I-410))

(DEFINDIVIDUAL "Financement annuel" ("année" "2013")
               ("montant" "60000") (:VAR _I-411))

(DEFINDIVIDUAL "Financement annuel" ("année" "2014")
               ("montant" "60000") (:VAR _I-412))

(DEFINDIVIDUAL "Financement annuel" ("année" "2015") ("montant" "2000")
               (:VAR _I-413))

(DEFINDIVIDUAL "Financement annuel" ("année" "2010") ("montant" "6274")
               (:VAR _I-414))

(DEFINDIVIDUAL "Financement annuel" ("année" "2011") ("montant" "6274")
               (:VAR _I-415))

(DEFINDIVIDUAL "Financement annuel" ("année" "2012") ("montant" "6274")
               (:VAR _I-416))

(DEFINDIVIDUAL "Financement annuel" ("année" "2013") ("montant" "6274")
               (:VAR _I-417))

(DEFINDIVIDUAL "Financement annuel" ("année" "2009") ("montant" "5173")
               (:VAR _I-426))

(DEFINDIVIDUAL "Financement annuel" ("année" "2010")
               ("montant" "18105") (:VAR _I-427))

(DEFINDIVIDUAL "Financement annuel" ("année" "2011")
               ("montant" "18105") (:VAR _I-428))

(DEFINDIVIDUAL "Financement annuel" ("année" "2012")
               ("montant" "18105") (:VAR _I-429))

(DEFINDIVIDUAL "Financement annuel" ("année" "2009")
               ("montant" "11109") (:VAR _I-444))

(DEFINDIVIDUAL "Financement annuel" ("année" "2010")
               ("montant" "11109") (:VAR _I-445))

(DEFINDIVIDUAL "Financement annuel" ("année" "2011")
               ("montant" "11109") (:VAR _I-446))

(DEFINDIVIDUAL "Financement annuel" ("année" "2012")
               ("montant" "11109") (:VAR _I-447))

(DEFINDIVIDUAL "Financement annuel" ("année" "2010")
               ("montant" "10747") (:VAR _I-455))

(DEFINDIVIDUAL "Financement annuel" ("année" "2011")
               ("montant" "10747") (:VAR _I-456))

(DEFINDIVIDUAL "Financement annuel" ("année" "2012")
               ("montant" "10747") (:VAR _I-457))

(DEFINDIVIDUAL "Financement annuel" ("année" "2013")
               ("montant" "10747") (:VAR _I-458))

(DEFINDIVIDUAL "Financement annuel" ("année" "2003")
               ("montant" "61575") (:VAR _I-464))

(DEFINDIVIDUAL "Financement annuel" ("année" "2004")
               ("montant" "61575") (:VAR _I-465))

(DEFINDIVIDUAL "Financement annuel" ("année" "2009")
               ("montant" "25850") (:VAR _I-466))

(DEFINDIVIDUAL "Financement annuel" ("année" "2010")
               ("montant" "25850") (:VAR _I-467))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "ICI") (:VAR _I-1264))
			   
(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "50")
               ("équipe" "DI") (:VAR _I-1265))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "50")
               ("équipe" "RO") (:VAR _I-1266))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "ICI") (:VAR _I-1267))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "ASER") (:VAR _I-1268))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "RO") (:VAR _I-1273))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "RO") (:VAR _I-1274))
			   
(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "ASER") (:VAR _I-1284))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "ICI") (:VAR _I-1288))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "ASER") (:VAR _I-1292))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "DI") (:VAR _I-1293))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "RO") (:VAR _I-1294))

(DEFINDIVIDUAL "Implication équipe" ("pourcentage" "100")
               ("équipe" "ICI") (:VAR _I-1295))

(DEFINDIVIDUAL "organisation"
               ("nom" "Organisation 1")
               ("sigle" "ORG1"))

(DEFINDIVIDUAL "pays" ("nom" (:EN "Brazil" :FR "Brésil")))

(DEFINDIVIDUAL "pays" ("nom" (:EN "Canada" :FR "Canada")))

(DEFINDIVIDUAL "pays" ("nom" (:EN "France " :FR "France")))

(DEFINDIVIDUAL "pays" ("nom" (:EN "Japan" :FR "Japon")))

(DEFINDIVIDUAL "pays"
               ("nom" (:EN "United Kingdom; UK" :FR "Royaume-Uni")))

(DEFINDIVIDUAL "personne" ("nom" "nom1") ("prénom" "prenom1")
               ("initiales du prénom" "p1") ("initiales" "n1p1"))
			   
(DEFINDIVIDUAL "personne" ("nom" "nom2") ("prénom" "prenom2")
               ("initiales du prénom" "p2") ("initiales" "n2p2"))
			   
(DEFINDIVIDUAL "personne" ("nom" "nom3") ("prénom" "prenom3")
               ("initiales du prénom" "p3") ("initiales" "n3p3"))

(DEFINDIVIDUAL "personne" ("nom" "nom4") ("prénom" "prenom4")
               ("initiales du prénom" "p4") ("initiales" "n4p4"))			   

;; TODO
(DEFINDIVIDUAL "Projet" ("titre" "Projet 1 (nom masqué)")
			   ("domaine" "apprentissage")
               ("résumé"
                "Détails du Projet 1 (masqué)")
               ("début" "2011") ("date de début" "1/1/2011")
               ("fin" "2013") ("date de fin" "1/1/2013") ("durée" "24")
               ("forme de contrat" "Subvention")
               ("financement" "PROJETS EUROPEENS")
               ("nb de projets" "1") ("nb de thèses" "0")
               ("aide totale heudiasyc H.T" "20000")
               ("état" "en cours") 
			   ("pays" "France")
               ("équipe" _I-1265 _I-1266)
               ("responsable scientifique" "prenom1")
               ("membres permanents" "prenom1")
               ("partenaire gestion"
                "Organisation-1")
               ("financement annuel" _I-407 _I-408 _I-409)
               (:VAR _I-1781))

(DEFINDIVIDUAL "Projet" ("titre" "Projet 2 (nom masqué)")
			   ("pays" "Brazil")
			   ("domaine" "apprentissage")
               ("résumé"
                "Résumé Masqué")
               ("date de dépôt" "7/22/2011") ("début" "2011")
               ("date de début" "10/1/2011") ("fin" "2015")
               ("date de fin" "4/1/2015") ("durée" "42")
               ("forme de contrat" "Collaboration de recherche")
               ("financement" "INDUSTRIEL") ("nb de projets" "1")
               ("nb de thèses" "0")
               ("aide totale heudiasyc H.T" "90000")
               ("état" "en cours") ("équipe" _I-1267)
               ("responsable scientifique" "prenom2")
               ("membres permanents" "prenom2")
               ("non permanents" "prenom3") ("partenaires" "Organisation-1")
               ("partenaire gestion" "Organisation-1")
               ("financement annuel" _I-410 _I-411 _I-412 _I-413)
               (:VAR _I-1782))

(DEFINDIVIDUAL "Projet" ("titre" "Projet 3 (nom masqué)")
			   ("domaine" "robotique")
               ("pays" "France")
               ("résumé"
                "Résumé Masqué")
               ("plateformes/ démos" "PACPUS") ("(H/mois) perm." "30")
               ("date de dépôt" "1/26/2010") ("début" "2010")
               ("date de début" "9/1/2010") ("fin" "2013")
               ("date de fin" "9/1/2013") ("durée" "36")
               ("forme de contrat" "Subvention")
               ("financement" "REGION") ("nb de projets" "1")
               ("nb de thèses" "0") ("aide totale partenaires" "10000")
               ("aide totale heudiasyc H.T" "30000")
               ("état" "en cours") ("équipe" _I-1268)
               ("responsable scientifique" "prenom3")
               ("membres permanents" "prenom3")
               ("partenaires" "Organisation-1")
               ("partenaire gestion"
                "Organisation-1")
               ("financement annuel" _I-414 _I-415 _I-416 _I-417)
               (:VAR _I-1783))

(DEFINDIVIDUAL "Projet" ("titre" "Projet 4 (nom masqué)")
			   ("domaine" "apprentissage")
               ("pays" "France")
               ("résumé"
                "Résumé Masqué")
               ("début" "2009") ("date de début" "7/1/2009")
               ("fin" "2014") ("date de fin" "7/1/2014") ("durée" "60")
               ("forme de contrat" "Subvention") ("financement" "ANR")
               ("nb de thèses" "0") ("aide totale heudiasyc H.T" "0")
               ("état" "en cours") ("équipe" _I-1273)
               ("responsable scientifique" "prenom1")
               ("membres permanents" "prenom1")
               ("partenaire gestion"
                "Organisation-1")
               (:VAR _I-1788))

(DEFINDIVIDUAL "Projet" ("titre" "Projet 5 (nom masqué)")
			   ("domaine" "robotique")
               ("pays" "France")
               ("résumé"
                "Résumé Masqué")
               ("unité budget" "I 159 C") ("plateformes/ démos" "RCSF")
               ("(H/mois) perm." "102") ("date de dépôt" "6/8/2009")
               ("début" "2009") ("date de début" "9/1/2009")
               ("fin" "2013") ("date de fin" "6/30/2013")
               ("durée" "46") ("forme de contrat" "Subvention")
               ("financement" "REGION/FEDER") ("nb de projets" "1")
               ("nb de thèses" "0")
               ("aide totale partenaires" "20000")
               ("aide totale heudiasyc H.T" "50000")
               ("commentaire" "axe agroressources") ("état" "en cours")
               ("équipe" _I-1274)
               ("responsable scientifique" "prenom3")
               ("membres permanents" "prenom3" "prenom2")
               ("partenaires" "Organisation-1")
               ("partenaire gestion"
                "Organisation-1")
               ("financement annuel" _I-426 _I-427 _I-428 _I-429)
               (:VAR _I-1789))

(DEFINDIVIDUAL "Projet" ("titre" "Projet 6 (nom masqué)")
			   ("domaine" "apprentissage")
               ("pays" "France")
               ("résumé"
                "Résumé Masqué")
               ("unité budget" "I 158 C") ("plateformes/ démos" "UAV")
               ("(H/mois) perm." "110") ("début" "2008")
               ("date de début" "10/8/2008") ("fin" "2014")
               ("date de fin" "12/31/2012") ("durée" "51")
               ("forme de contrat" "Subvention")
               ("financement" "REGION") ("nb de projets" "1")
               ("nb de thèses" "0") ("aide totale partenaires" "60000")
               ("aide totale heudiasyc H.T" "50000")
               ("état" "en cours") ("équipe" _I-1284)
               ("responsable scientifique" "prenom4")
               ("membres permanents" "prenom4")
               ("partenaires" "Organisation-1")
               ("partenaire gestion"
                "Organisation-1")
               ("financement annuel" _I-444 _I-445 _I-446 _I-447)
               (:VAR _I-1798))

(DEFINDIVIDUAL "Projet" ("titre" "Projet 7 (nom masqué)")
			   ("domaine" "apprentissage")
               ("pays" "France")
               ("résumé"
                "Résumé Masqué")
               ("plateformes/ démos" "PVA") ("(H/mois) perm." "12,6")
               ("date de dépôt" "2/2/2010") ("début" "2010")
               ("date de début" "9/1/2010") ("fin" "2013")
               ("date de fin" "9/1/2013") ("durée" "36")
               ("forme de contrat" "Subvention")
               ("financement" "REGION") ("nb de projets" "1")
               ("nb de thèses" "0") ("aide totale partenaires" "60000")
               ("aide totale heudiasyc H.T" "40000")
               ("état" "en cours") ("équipe" _I-1288)
               ("responsable scientifique" "prenom4")
               ("membres permanents" "prenom4")
               ("partenaires" "Organisation-1")
               ("partenaire gestion"
                "Organisation-1")
               ("financement annuel" _I-455 _I-456 _I-457 _I-458)
               (:VAR _I-1802))

(DEFINDIVIDUAL "Projet" ("titre" "Projet 8 (nom masqué)")     
			   ("domaine" "apprentissage")      
               ("pays" "France")
               ("résumé"
                "Résumé Masqué")
               ("(H/mois) perm." "64") ("date de dépôt" "9/26/2011")
               ("début" "2012") ("fin" "2015") ("durée" "48")
               ("forme de contrat" "Collaboration de recherche")
               ("financement" "ANR") ("nb de thèses" "0")
               ("aide totale partenaires" "50000")
               ("aide totale heudiasyc H.T" "12000") ("état" "en cours")
               ("équipe" _I-1292)
               ("responsable scientifique" "prenom2")
               ("membres permanents" "prenom2" "prenom3")
               ("partenaires" "Organisation-1")
               ("partenaire gestion"
                "Organisation-1")
               (:VAR _I-1806))

(DEFINDIVIDUAL "Projet" ("titre" "Projet 9 (nom masqué)")
			   ("domaine" "apprentissage")
               ("pays" "France")
               ("résumé"
                "Résumé Masqué")
               ("plateformes/ démos" "FACE ANALYSIS") ("début" "2012")
               ("date de début" "1/1/2012") ("fin" "2014")
               ("date de fin" "1/1/2014") ("durée" "24")
               ("forme de contrat" "Subvention") ("financement" "ANR")
               ("nb de projets" "1") ("nb de thèses" "0")
               ("aide totale heudiasyc H.T" "45000")
               ("commentaire" "RNRT") ("état" "en cours")
               ("équipe" _I-1293)
               ("responsable scientifique" "prenom1")
               ("membres permanents" "prenom1")
               ("partenaire gestion"
                "Organisation-1")
               ("financement annuel" _I-464 _I-465) (:VAR _I-1807))

(DEFINDIVIDUAL "Projet" ("titre" "Projet 10 (nom masqué)")
			   ("domaine" "apprentissage")
			   ("pays" "France")
			   ("résumé"
                "Résumé Masqué")
               ("(H/mois) perm." "0,1") ("date de dépôt" "5/1/2009")
               ("début" "2010") ("date de début" "5/1/2010")
               ("fin" "2014") ("date de fin" "5/1/2014")
               ("durée" "36")
               ("forme de contrat" "Prestation de service")
               ("financement" "INDUSTRIEL") ("nb de projets" "1")
               ("nb de thèses" "0")
               ("aide totale heudiasyc H.T" "51700") ("état" "en cours")
               ("équipe" _I-1294)
               ("responsable scientifique" "prenom3")
               ("membres permanents" "prenom2" "prenom3")
               ("partenaires" "Organisation-1") ("partenaire gestion" "Organisation-1")
               ("financement annuel" _I-466 _I-467) (:VAR _I-1808))

(DEFINDIVIDUAL "Projet" ("titre" "Projet 11 (nom masqué)")
			   ("domaine" "apprentissage")
               ("pays" "France") 
			   ("résumé"
                "Résumé Masqué")
               ("(H/mois) perm." "3") ("date de dépôt" "12/16/2010")
               ("début" "2011") ("date de début" "9/1/2011")
               ("fin" "2014") ("date de fin" "9/1/2014") ("durée" "36")
               ("forme de contrat" "Subvention")
               ("financement" "REGION") ("nb de thèses" "0")
               ("aide totale partenaires" "459463")
               ("aide totale heudiasyc H.T" "0") ("état" "en cours")
               ("équipe" _I-1295)
               ("responsable scientifique" "prenom1")
               ("membres permanents" "prenom1")
               ("partenaires" "Organisation-1")
               ("partenaire gestion"
                "Organisation-1")
               (:VAR _I-1809))

(DEFINDIVIDUAL "Équipe" ("sigle" "ASER")
               ("membre" "prenom1"))
			   
(DEFINDIVIDUAL "Équipe" ("sigle" "ICI")
               ("membre" "prenom2"))

(DEFINDIVIDUAL "Équipe" ("sigle" "DI")
               ("membre" "prenom3"))

(DEFINDIVIDUAL "Équipe" ("sigle" "RO")
               ("membre" "prenom4"))

:EOF