﻿/**
 * Set of functions for chart visualization
 * Author: Marcio Fuckner
 *
 * Revision history:
 * 01/11/2013 - MFK - First version. 
 */

/**
 * Render a chart in the specified div
 * Parameters:
 *  message: The response message
 *  div: the div to be used
 */
function renderChart(message,divName) {

   var chartObject = {};
   chartObject["title"] = { "text" : ""};
   chartObject["height"] = 400;
   chartObject["width"] = 700;
   chartObject["legend"] = {
                             verticalAlign: "center",
                             horizontalAlign: "left",
                             fontSize: 20,
                             fontFamily: "Helvetica"        
                           };
	chartObject["theme"] = "theme2";

	// create data object
	data = {};
	data["type"] = message["chart-type"][0];
	data["indexLabelFontFamily"] = "Garamond";       
    data["indexLabelFontSize"] = 20;
    data["startAngle"] = -20;      
    data["showInLegend"] = false;
    data["toolTipContent"] = "{legendText}";
	
	var datapoints = [];
	for(var i=0;i<message.content.length;i++) {
	   var elem = message.content[i];
	   
	   // build the label
	   var labelValue = "";
	   for(prop in message.categories) {
	      labelValue += " " + elem[message.categories[prop]] 
	   }
	   labelValue = labelValue.trim();
	   
	   // build value
	   var value = 0, pattern = /\((.+?)\)/g; 
	   for(att in elem) {
	     var matches = att.match(pattern);
		 if(matches != null) {
		    var attrWork = matches[0].substring(1,matches[0].length-1);
			if(attrWork == message.attribute) {
			   value = parseFloat(elem[att]);
			}
		 }
	   }
	   
	   var title = labelValue + " " + message["group-function"] + "(" +
									message.attribute + ") = " + value;
	   
	   // create a datapoint
	   var datapoint = { y : value, legendText : title, label : labelValue };
       datapoints.push(datapoint);	   
	}
	data["dataPoints"] = datapoints;
	
	// add data to chartobject
	chartObject["data"] = [];
	chartObject["data"].push(data);
	
	// create chart rendering object
	var chartRenderObject = new CanvasJS.Chart(divName,chartObject);
	chartRenderObject.render();
}

/* EOF */